"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class PreloadedUserSettings(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _InboxTab:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _InboxTabEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._InboxTab.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        INBOX_TAB_UNSPECIFIED: PreloadedUserSettings._InboxTab.ValueType  # 0
        INBOX_TAB_MENTIONS: PreloadedUserSettings._InboxTab.ValueType  # 1
        INBOX_TAB_UNREADS: PreloadedUserSettings._InboxTab.ValueType  # 2
        INBOX_TAB_TODOS: PreloadedUserSettings._InboxTab.ValueType  # 3
        INBOX_TAB_FOR_YOU: PreloadedUserSettings._InboxTab.ValueType  # 4
        INBOX_TAB_GAME_INVITES: PreloadedUserSettings._InboxTab.ValueType  # 5
        INBOX_TAB_BOOKMARKS: PreloadedUserSettings._InboxTab.ValueType  # 6
        INBOX_TAB_SCHEDULED: PreloadedUserSettings._InboxTab.ValueType  # 7

    class InboxTab(_InboxTab, metaclass=_InboxTabEnumTypeWrapper): ...
    INBOX_TAB_UNSPECIFIED: PreloadedUserSettings.InboxTab.ValueType  # 0
    INBOX_TAB_MENTIONS: PreloadedUserSettings.InboxTab.ValueType  # 1
    INBOX_TAB_UNREADS: PreloadedUserSettings.InboxTab.ValueType  # 2
    INBOX_TAB_TODOS: PreloadedUserSettings.InboxTab.ValueType  # 3
    INBOX_TAB_FOR_YOU: PreloadedUserSettings.InboxTab.ValueType  # 4
    INBOX_TAB_GAME_INVITES: PreloadedUserSettings.InboxTab.ValueType  # 5
    INBOX_TAB_BOOKMARKS: PreloadedUserSettings.InboxTab.ValueType  # 6
    INBOX_TAB_SCHEDULED: PreloadedUserSettings.InboxTab.ValueType  # 7

    class _DmSpamFilterV2:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _DmSpamFilterV2EnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._DmSpamFilterV2.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        DM_SPAM_FILTER_V2_DEFAULT_UNSET: PreloadedUserSettings._DmSpamFilterV2.ValueType  # 0
        DM_SPAM_FILTER_V2_DISABLED: PreloadedUserSettings._DmSpamFilterV2.ValueType  # 1
        DM_SPAM_FILTER_V2_NON_FRIENDS: PreloadedUserSettings._DmSpamFilterV2.ValueType  # 2
        DM_SPAM_FILTER_V2_FRIENDS_AND_NON_FRIENDS: PreloadedUserSettings._DmSpamFilterV2.ValueType  # 3

    class DmSpamFilterV2(_DmSpamFilterV2, metaclass=_DmSpamFilterV2EnumTypeWrapper): ...
    DM_SPAM_FILTER_V2_DEFAULT_UNSET: PreloadedUserSettings.DmSpamFilterV2.ValueType  # 0
    DM_SPAM_FILTER_V2_DISABLED: PreloadedUserSettings.DmSpamFilterV2.ValueType  # 1
    DM_SPAM_FILTER_V2_NON_FRIENDS: PreloadedUserSettings.DmSpamFilterV2.ValueType  # 2
    DM_SPAM_FILTER_V2_FRIENDS_AND_NON_FRIENDS: PreloadedUserSettings.DmSpamFilterV2.ValueType  # 3

    class _ExplicitContentRedaction:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ExplicitContentRedactionEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._ExplicitContentRedaction.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        EXPLICIT_CONTENT_REDACTION_UNSET_EXPLICIT_CONTENT_REDACTION: PreloadedUserSettings._ExplicitContentRedaction.ValueType  # 0
        EXPLICIT_CONTENT_REDACTION_SHOW: PreloadedUserSettings._ExplicitContentRedaction.ValueType  # 1
        EXPLICIT_CONTENT_REDACTION_BLUR: PreloadedUserSettings._ExplicitContentRedaction.ValueType  # 2
        EXPLICIT_CONTENT_REDACTION_BLOCK: PreloadedUserSettings._ExplicitContentRedaction.ValueType  # 3

    class ExplicitContentRedaction(_ExplicitContentRedaction, metaclass=_ExplicitContentRedactionEnumTypeWrapper): ...
    EXPLICIT_CONTENT_REDACTION_UNSET_EXPLICIT_CONTENT_REDACTION: PreloadedUserSettings.ExplicitContentRedaction.ValueType  # 0
    EXPLICIT_CONTENT_REDACTION_SHOW: PreloadedUserSettings.ExplicitContentRedaction.ValueType  # 1
    EXPLICIT_CONTENT_REDACTION_BLUR: PreloadedUserSettings.ExplicitContentRedaction.ValueType  # 2
    EXPLICIT_CONTENT_REDACTION_BLOCK: PreloadedUserSettings.ExplicitContentRedaction.ValueType  # 3

    class _ReactionNotificationType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ReactionNotificationTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._ReactionNotificationType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        REACTION_NOTIFICATION_TYPE_NOTIFICATIONS_ENABLED: PreloadedUserSettings._ReactionNotificationType.ValueType  # 0
        REACTION_NOTIFICATION_TYPE_ONLY_DMS: PreloadedUserSettings._ReactionNotificationType.ValueType  # 1
        REACTION_NOTIFICATION_TYPE_NOTIFICATIONS_DISABLED: PreloadedUserSettings._ReactionNotificationType.ValueType  # 2

    class ReactionNotificationType(_ReactionNotificationType, metaclass=_ReactionNotificationTypeEnumTypeWrapper): ...
    REACTION_NOTIFICATION_TYPE_NOTIFICATIONS_ENABLED: PreloadedUserSettings.ReactionNotificationType.ValueType  # 0
    REACTION_NOTIFICATION_TYPE_ONLY_DMS: PreloadedUserSettings.ReactionNotificationType.ValueType  # 1
    REACTION_NOTIFICATION_TYPE_NOTIFICATIONS_DISABLED: PreloadedUserSettings.ReactionNotificationType.ValueType  # 2

    class _GameActivityNotificationType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _GameActivityNotificationTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._GameActivityNotificationType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        GAME_ACTIVITY_NOTIFICATION_TYPE_ACTIVITY_NOTIFICATIONS_UNSET: PreloadedUserSettings._GameActivityNotificationType.ValueType  # 0
        GAME_ACTIVITY_NOTIFICATION_TYPE_ACTIVITY_NOTIFICATIONS_DISABLED: PreloadedUserSettings._GameActivityNotificationType.ValueType  # 1
        GAME_ACTIVITY_NOTIFICATION_TYPE_ACTIVITY_NOTIFICATIONS_ENABLED: PreloadedUserSettings._GameActivityNotificationType.ValueType  # 2
        GAME_ACTIVITY_NOTIFICATION_TYPE_ONLY_GAMES_PLAYED: PreloadedUserSettings._GameActivityNotificationType.ValueType  # 3

    class GameActivityNotificationType(_GameActivityNotificationType, metaclass=_GameActivityNotificationTypeEnumTypeWrapper): ...
    GAME_ACTIVITY_NOTIFICATION_TYPE_ACTIVITY_NOTIFICATIONS_UNSET: PreloadedUserSettings.GameActivityNotificationType.ValueType  # 0
    GAME_ACTIVITY_NOTIFICATION_TYPE_ACTIVITY_NOTIFICATIONS_DISABLED: PreloadedUserSettings.GameActivityNotificationType.ValueType  # 1
    GAME_ACTIVITY_NOTIFICATION_TYPE_ACTIVITY_NOTIFICATIONS_ENABLED: PreloadedUserSettings.GameActivityNotificationType.ValueType  # 2
    GAME_ACTIVITY_NOTIFICATION_TYPE_ONLY_GAMES_PLAYED: PreloadedUserSettings.GameActivityNotificationType.ValueType  # 3

    class _CustomStatusPushNotificationType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _CustomStatusPushNotificationTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._CustomStatusPushNotificationType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        CUSTOM_STATUS_PUSH_NOTIFICATION_TYPE_STATUS_PUSH_UNSET: PreloadedUserSettings._CustomStatusPushNotificationType.ValueType  # 0
        CUSTOM_STATUS_PUSH_NOTIFICATION_TYPE_STATUS_PUSH_ENABLED: PreloadedUserSettings._CustomStatusPushNotificationType.ValueType  # 1
        CUSTOM_STATUS_PUSH_NOTIFICATION_TYPE_STATUS_PUSH_DISABLED: PreloadedUserSettings._CustomStatusPushNotificationType.ValueType  # 2

    class CustomStatusPushNotificationType(_CustomStatusPushNotificationType, metaclass=_CustomStatusPushNotificationTypeEnumTypeWrapper): ...
    CUSTOM_STATUS_PUSH_NOTIFICATION_TYPE_STATUS_PUSH_UNSET: PreloadedUserSettings.CustomStatusPushNotificationType.ValueType  # 0
    CUSTOM_STATUS_PUSH_NOTIFICATION_TYPE_STATUS_PUSH_ENABLED: PreloadedUserSettings.CustomStatusPushNotificationType.ValueType  # 1
    CUSTOM_STATUS_PUSH_NOTIFICATION_TYPE_STATUS_PUSH_DISABLED: PreloadedUserSettings.CustomStatusPushNotificationType.ValueType  # 2

    class _GuildActivityStatusRestrictionDefault:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _GuildActivityStatusRestrictionDefaultEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._GuildActivityStatusRestrictionDefault.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_OFF: PreloadedUserSettings._GuildActivityStatusRestrictionDefault.ValueType  # 0
        GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_ON_FOR_LARGE_GUILDS: PreloadedUserSettings._GuildActivityStatusRestrictionDefault.ValueType  # 1
        GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_ON: PreloadedUserSettings._GuildActivityStatusRestrictionDefault.ValueType  # 2

    class GuildActivityStatusRestrictionDefault(_GuildActivityStatusRestrictionDefault, metaclass=_GuildActivityStatusRestrictionDefaultEnumTypeWrapper): ...
    GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_OFF: PreloadedUserSettings.GuildActivityStatusRestrictionDefault.ValueType  # 0
    GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_ON_FOR_LARGE_GUILDS: PreloadedUserSettings.GuildActivityStatusRestrictionDefault.ValueType  # 1
    GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_ON: PreloadedUserSettings.GuildActivityStatusRestrictionDefault.ValueType  # 2

    class _GuildsLeaderboardOptOutDefault:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _GuildsLeaderboardOptOutDefaultEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._GuildsLeaderboardOptOutDefault.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        GUILDS_LEADERBOARD_OPT_OUT_DEFAULT_OFF_FOR_NEW_GUILDS: PreloadedUserSettings._GuildsLeaderboardOptOutDefault.ValueType  # 0
        GUILDS_LEADERBOARD_OPT_OUT_DEFAULT_ON_FOR_NEW_GUILDS: PreloadedUserSettings._GuildsLeaderboardOptOutDefault.ValueType  # 1

    class GuildsLeaderboardOptOutDefault(_GuildsLeaderboardOptOutDefault, metaclass=_GuildsLeaderboardOptOutDefaultEnumTypeWrapper): ...
    GUILDS_LEADERBOARD_OPT_OUT_DEFAULT_OFF_FOR_NEW_GUILDS: PreloadedUserSettings.GuildsLeaderboardOptOutDefault.ValueType  # 0
    GUILDS_LEADERBOARD_OPT_OUT_DEFAULT_ON_FOR_NEW_GUILDS: PreloadedUserSettings.GuildsLeaderboardOptOutDefault.ValueType  # 1

    class _SlayerSDKReceiveInGameDMs:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _SlayerSDKReceiveInGameDMsEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._SlayerSDKReceiveInGameDMs.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        SLAYER_SDK_RECEIVE_IN_GAME_DMS_UNSET: PreloadedUserSettings._SlayerSDKReceiveInGameDMs.ValueType  # 0
        SLAYER_SDK_RECEIVE_IN_GAME_DMS_ALL: PreloadedUserSettings._SlayerSDKReceiveInGameDMs.ValueType  # 1
        SLAYER_SDK_RECEIVE_IN_GAME_DMS_USERS_WITH_GAME: PreloadedUserSettings._SlayerSDKReceiveInGameDMs.ValueType  # 2
        SLAYER_SDK_RECEIVE_IN_GAME_DMS_NONE: PreloadedUserSettings._SlayerSDKReceiveInGameDMs.ValueType  # 3

    class SlayerSDKReceiveInGameDMs(_SlayerSDKReceiveInGameDMs, metaclass=_SlayerSDKReceiveInGameDMsEnumTypeWrapper): ...
    SLAYER_SDK_RECEIVE_IN_GAME_DMS_UNSET: PreloadedUserSettings.SlayerSDKReceiveInGameDMs.ValueType  # 0
    SLAYER_SDK_RECEIVE_IN_GAME_DMS_ALL: PreloadedUserSettings.SlayerSDKReceiveInGameDMs.ValueType  # 1
    SLAYER_SDK_RECEIVE_IN_GAME_DMS_USERS_WITH_GAME: PreloadedUserSettings.SlayerSDKReceiveInGameDMs.ValueType  # 2
    SLAYER_SDK_RECEIVE_IN_GAME_DMS_NONE: PreloadedUserSettings.SlayerSDKReceiveInGameDMs.ValueType  # 3

    class _GuildActivityStatusRestrictionDefaultV2:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _GuildActivityStatusRestrictionDefaultV2EnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._GuildActivityStatusRestrictionDefaultV2.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_V2_ACTIVITY_STATUS_UNSET: PreloadedUserSettings._GuildActivityStatusRestrictionDefaultV2.ValueType  # 0
        GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_V2_ACTIVITY_STATUS_OFF: PreloadedUserSettings._GuildActivityStatusRestrictionDefaultV2.ValueType  # 1
        GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_V2_ACTIVITY_STATUS_ON_FOR_LARGE_GUILDS: PreloadedUserSettings._GuildActivityStatusRestrictionDefaultV2.ValueType  # 2
        GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_V2_ACTIVITY_STATUS_ON: PreloadedUserSettings._GuildActivityStatusRestrictionDefaultV2.ValueType  # 3

    class GuildActivityStatusRestrictionDefaultV2(_GuildActivityStatusRestrictionDefaultV2, metaclass=_GuildActivityStatusRestrictionDefaultV2EnumTypeWrapper): ...
    GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_V2_ACTIVITY_STATUS_UNSET: PreloadedUserSettings.GuildActivityStatusRestrictionDefaultV2.ValueType  # 0
    GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_V2_ACTIVITY_STATUS_OFF: PreloadedUserSettings.GuildActivityStatusRestrictionDefaultV2.ValueType  # 1
    GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_V2_ACTIVITY_STATUS_ON_FOR_LARGE_GUILDS: PreloadedUserSettings.GuildActivityStatusRestrictionDefaultV2.ValueType  # 2
    GUILD_ACTIVITY_STATUS_RESTRICTION_DEFAULT_V2_ACTIVITY_STATUS_ON: PreloadedUserSettings.GuildActivityStatusRestrictionDefaultV2.ValueType  # 3

    class _ProfileVisibility:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ProfileVisibilityEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._ProfileVisibility.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        PROFILE_VISIBILITY_UNSET: PreloadedUserSettings._ProfileVisibility.ValueType  # 0
        PROFILE_VISIBILITY_FRIENDS_ONLY: PreloadedUserSettings._ProfileVisibility.ValueType  # 1
        PROFILE_VISIBILITY_FRIENDS_AND_SMALL_GUILDS: PreloadedUserSettings._ProfileVisibility.ValueType  # 2
        PROFILE_VISIBILITY_FRIENDS_AND_ALL_GUILDS: PreloadedUserSettings._ProfileVisibility.ValueType  # 3

    class ProfileVisibility(_ProfileVisibility, metaclass=_ProfileVisibilityEnumTypeWrapper): ...
    PROFILE_VISIBILITY_UNSET: PreloadedUserSettings.ProfileVisibility.ValueType  # 0
    PROFILE_VISIBILITY_FRIENDS_ONLY: PreloadedUserSettings.ProfileVisibility.ValueType  # 1
    PROFILE_VISIBILITY_FRIENDS_AND_SMALL_GUILDS: PreloadedUserSettings.ProfileVisibility.ValueType  # 2
    PROFILE_VISIBILITY_FRIENDS_AND_ALL_GUILDS: PreloadedUserSettings.ProfileVisibility.ValueType  # 3

    class _Theme:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ThemeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._Theme.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        THEME_UNSET: PreloadedUserSettings._Theme.ValueType  # 0
        THEME_DARK: PreloadedUserSettings._Theme.ValueType  # 1
        THEME_LIGHT: PreloadedUserSettings._Theme.ValueType  # 2
        THEME_DARKER: PreloadedUserSettings._Theme.ValueType  # 3
        THEME_MIDNIGHT: PreloadedUserSettings._Theme.ValueType  # 4

    class Theme(_Theme, metaclass=_ThemeEnumTypeWrapper): ...
    THEME_UNSET: PreloadedUserSettings.Theme.ValueType  # 0
    THEME_DARK: PreloadedUserSettings.Theme.ValueType  # 1
    THEME_LIGHT: PreloadedUserSettings.Theme.ValueType  # 2
    THEME_DARKER: PreloadedUserSettings.Theme.ValueType  # 3
    THEME_MIDNIGHT: PreloadedUserSettings.Theme.ValueType  # 4

    class _TimestampHourCycle:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _TimestampHourCycleEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._TimestampHourCycle.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        TIMESTAMP_HOUR_CYCLE_AUTO: PreloadedUserSettings._TimestampHourCycle.ValueType  # 0
        TIMESTAMP_HOUR_CYCLE_H12: PreloadedUserSettings._TimestampHourCycle.ValueType  # 1
        TIMESTAMP_HOUR_CYCLE_H23: PreloadedUserSettings._TimestampHourCycle.ValueType  # 2

    class TimestampHourCycle(_TimestampHourCycle, metaclass=_TimestampHourCycleEnumTypeWrapper): ...
    TIMESTAMP_HOUR_CYCLE_AUTO: PreloadedUserSettings.TimestampHourCycle.ValueType  # 0
    TIMESTAMP_HOUR_CYCLE_H12: PreloadedUserSettings.TimestampHourCycle.ValueType  # 1
    TIMESTAMP_HOUR_CYCLE_H23: PreloadedUserSettings.TimestampHourCycle.ValueType  # 2

    class _LaunchPadMode:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _LaunchPadModeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._LaunchPadMode.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        LAUNCH_PAD_MODE_LAUNCH_PAD_DISABLED: PreloadedUserSettings._LaunchPadMode.ValueType  # 0
        LAUNCH_PAD_MODE_LAUNCH_PAD_GESTURE_FULL_SCREEN: PreloadedUserSettings._LaunchPadMode.ValueType  # 1
        LAUNCH_PAD_MODE_LAUNCH_PAD_GESTURE_RIGHT_EDGE: PreloadedUserSettings._LaunchPadMode.ValueType  # 2
        LAUNCH_PAD_MODE_LAUNCH_PAD_PULL_TAB: PreloadedUserSettings._LaunchPadMode.ValueType  # 3

    class LaunchPadMode(_LaunchPadMode, metaclass=_LaunchPadModeEnumTypeWrapper): ...
    LAUNCH_PAD_MODE_LAUNCH_PAD_DISABLED: PreloadedUserSettings.LaunchPadMode.ValueType  # 0
    LAUNCH_PAD_MODE_LAUNCH_PAD_GESTURE_FULL_SCREEN: PreloadedUserSettings.LaunchPadMode.ValueType  # 1
    LAUNCH_PAD_MODE_LAUNCH_PAD_GESTURE_RIGHT_EDGE: PreloadedUserSettings.LaunchPadMode.ValueType  # 2
    LAUNCH_PAD_MODE_LAUNCH_PAD_PULL_TAB: PreloadedUserSettings.LaunchPadMode.ValueType  # 3

    class _UIDensity:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _UIDensityEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._UIDensity.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        UI_DENSITY_UNSET_UI_DENSITY: PreloadedUserSettings._UIDensity.ValueType  # 0
        UI_DENSITY_COMPACT: PreloadedUserSettings._UIDensity.ValueType  # 1
        UI_DENSITY_COZY: PreloadedUserSettings._UIDensity.ValueType  # 2
        UI_DENSITY_RESPONSIVE: PreloadedUserSettings._UIDensity.ValueType  # 3
        UI_DENSITY_DEFAULT: PreloadedUserSettings._UIDensity.ValueType  # 4

    class UIDensity(_UIDensity, metaclass=_UIDensityEnumTypeWrapper): ...
    UI_DENSITY_UNSET_UI_DENSITY: PreloadedUserSettings.UIDensity.ValueType  # 0
    UI_DENSITY_COMPACT: PreloadedUserSettings.UIDensity.ValueType  # 1
    UI_DENSITY_COZY: PreloadedUserSettings.UIDensity.ValueType  # 2
    UI_DENSITY_RESPONSIVE: PreloadedUserSettings.UIDensity.ValueType  # 3
    UI_DENSITY_DEFAULT: PreloadedUserSettings.UIDensity.ValueType  # 4

    class _SwipeRightToLeftMode:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _SwipeRightToLeftModeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._SwipeRightToLeftMode.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        SWIPE_RIGHT_TO_LEFT_MODE_SWIPE_RIGHT_TO_LEFT_UNSET: PreloadedUserSettings._SwipeRightToLeftMode.ValueType  # 0
        SWIPE_RIGHT_TO_LEFT_MODE_SWIPE_RIGHT_TO_LEFT_CHANNEL_DETAILS: PreloadedUserSettings._SwipeRightToLeftMode.ValueType  # 1
        SWIPE_RIGHT_TO_LEFT_MODE_SWIPE_RIGHT_TO_LEFT_REPLY: PreloadedUserSettings._SwipeRightToLeftMode.ValueType  # 2

    class SwipeRightToLeftMode(_SwipeRightToLeftMode, metaclass=_SwipeRightToLeftModeEnumTypeWrapper): ...
    SWIPE_RIGHT_TO_LEFT_MODE_SWIPE_RIGHT_TO_LEFT_UNSET: PreloadedUserSettings.SwipeRightToLeftMode.ValueType  # 0
    SWIPE_RIGHT_TO_LEFT_MODE_SWIPE_RIGHT_TO_LEFT_CHANNEL_DETAILS: PreloadedUserSettings.SwipeRightToLeftMode.ValueType  # 1
    SWIPE_RIGHT_TO_LEFT_MODE_SWIPE_RIGHT_TO_LEFT_REPLY: PreloadedUserSettings.SwipeRightToLeftMode.ValueType  # 2

    class _FavoriteChannelType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _FavoriteChannelTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._FavoriteChannelType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        FAVORITE_CHANNEL_TYPE_UNSET_FAVORITE_CHANNEL_TYPE: PreloadedUserSettings._FavoriteChannelType.ValueType  # 0
        FAVORITE_CHANNEL_TYPE_REFERENCE_ORIGINAL: PreloadedUserSettings._FavoriteChannelType.ValueType  # 1
        FAVORITE_CHANNEL_TYPE_CATEGORY: PreloadedUserSettings._FavoriteChannelType.ValueType  # 2

    class FavoriteChannelType(_FavoriteChannelType, metaclass=_FavoriteChannelTypeEnumTypeWrapper): ...
    FAVORITE_CHANNEL_TYPE_UNSET_FAVORITE_CHANNEL_TYPE: PreloadedUserSettings.FavoriteChannelType.ValueType  # 0
    FAVORITE_CHANNEL_TYPE_REFERENCE_ORIGINAL: PreloadedUserSettings.FavoriteChannelType.ValueType  # 1
    FAVORITE_CHANNEL_TYPE_CATEGORY: PreloadedUserSettings.FavoriteChannelType.ValueType  # 2

    class _ForLaterTab:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ForLaterTabEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._ForLaterTab.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        FOR_LATER_TAB_UNSPECIFIED: PreloadedUserSettings._ForLaterTab.ValueType  # 0
        FOR_LATER_TAB_ALL: PreloadedUserSettings._ForLaterTab.ValueType  # 1
        FOR_LATER_TAB_BOOKMARKS: PreloadedUserSettings._ForLaterTab.ValueType  # 2
        FOR_LATER_TAB_REMINDERS: PreloadedUserSettings._ForLaterTab.ValueType  # 3

    class ForLaterTab(_ForLaterTab, metaclass=_ForLaterTabEnumTypeWrapper): ...
    FOR_LATER_TAB_UNSPECIFIED: PreloadedUserSettings.ForLaterTab.ValueType  # 0
    FOR_LATER_TAB_ALL: PreloadedUserSettings.ForLaterTab.ValueType  # 1
    FOR_LATER_TAB_BOOKMARKS: PreloadedUserSettings.ForLaterTab.ValueType  # 2
    FOR_LATER_TAB_REMINDERS: PreloadedUserSettings.ForLaterTab.ValueType  # 3

    class _SafetySettingsPresetType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _SafetySettingsPresetTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PreloadedUserSettings._SafetySettingsPresetType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        SAFETY_SETTINGS_PRESET_TYPE_UNSET_SAFETY_SETTINGS_PRESET: PreloadedUserSettings._SafetySettingsPresetType.ValueType  # 0
        SAFETY_SETTINGS_PRESET_TYPE_BALANCED: PreloadedUserSettings._SafetySettingsPresetType.ValueType  # 1
        SAFETY_SETTINGS_PRESET_TYPE_STRICT: PreloadedUserSettings._SafetySettingsPresetType.ValueType  # 2
        SAFETY_SETTINGS_PRESET_TYPE_RELAXED: PreloadedUserSettings._SafetySettingsPresetType.ValueType  # 3
        SAFETY_SETTINGS_PRESET_TYPE_CUSTOM: PreloadedUserSettings._SafetySettingsPresetType.ValueType  # 4

    class SafetySettingsPresetType(_SafetySettingsPresetType, metaclass=_SafetySettingsPresetTypeEnumTypeWrapper): ...
    SAFETY_SETTINGS_PRESET_TYPE_UNSET_SAFETY_SETTINGS_PRESET: PreloadedUserSettings.SafetySettingsPresetType.ValueType  # 0
    SAFETY_SETTINGS_PRESET_TYPE_BALANCED: PreloadedUserSettings.SafetySettingsPresetType.ValueType  # 1
    SAFETY_SETTINGS_PRESET_TYPE_STRICT: PreloadedUserSettings.SafetySettingsPresetType.ValueType  # 2
    SAFETY_SETTINGS_PRESET_TYPE_RELAXED: PreloadedUserSettings.SafetySettingsPresetType.ValueType  # 3
    SAFETY_SETTINGS_PRESET_TYPE_CUSTOM: PreloadedUserSettings.SafetySettingsPresetType.ValueType  # 4

    @_typing.final
    class Versions(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        CLIENT_VERSION_FIELD_NUMBER: _builtins.int
        SERVER_VERSION_FIELD_NUMBER: _builtins.int
        DATA_VERSION_FIELD_NUMBER: _builtins.int
        client_version: _builtins.int
        server_version: _builtins.int
        data_version: _builtins.int
        def __init__(
            self,
            *,
            client_version: _builtins.int = ...,
            server_version: _builtins.int = ...,
            data_version: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["client_version", b"client_version", "data_version", b"data_version", "server_version", b"server_version"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class InboxSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        CURRENT_TAB_FIELD_NUMBER: _builtins.int
        VIEWED_TUTORIAL_FIELD_NUMBER: _builtins.int
        current_tab: Global___PreloadedUserSettings.InboxTab.ValueType
        viewed_tutorial: _builtins.bool
        def __init__(
            self,
            *,
            current_tab: Global___PreloadedUserSettings.InboxTab.ValueType = ...,
            viewed_tutorial: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["current_tab", b"current_tab", "viewed_tutorial", b"viewed_tutorial"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class ChannelIconEmoji(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ID_FIELD_NUMBER: _builtins.int
        NAME_FIELD_NUMBER: _builtins.int
        COLOR_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def id(self) -> _wrappers_pb2.UInt64Value: ...
        @_builtins.property
        def name(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def color(self) -> _wrappers_pb2.UInt64Value: ...
        def __init__(
            self,
            *,
            id: _wrappers_pb2.UInt64Value | None = ...,
            name: _wrappers_pb2.StringValue | None = ...,
            color: _wrappers_pb2.UInt64Value | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_color", b"_color", "_id", b"_id", "_name", b"_name", "color", b"color", "id", b"id", "name", b"name"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_color", b"_color", "_id", b"_id", "_name", b"_name", "color", b"color", "id", b"id", "name", b"name"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__color: _TypeAlias = _typing.Literal["color"]  # noqa: Y015
        _WhichOneofArgType__color: _TypeAlias = _typing.Literal["_color", b"_color"]  # noqa: Y015
        _WhichOneofReturnType__id: _TypeAlias = _typing.Literal["id"]  # noqa: Y015
        _WhichOneofArgType__id: _TypeAlias = _typing.Literal["_id", b"_id"]  # noqa: Y015
        _WhichOneofReturnType__name: _TypeAlias = _typing.Literal["name"]  # noqa: Y015
        _WhichOneofArgType__name: _TypeAlias = _typing.Literal["_name", b"_name"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__color) -> _WhichOneofReturnType__color | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__id) -> _WhichOneofReturnType__id | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__name) -> _WhichOneofReturnType__name | None: ...

    @_typing.final
    class CustomNotificationSoundConfig(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        NOTIFICATION_SOUND_PACK_ID_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def notification_sound_pack_id(self) -> _wrappers_pb2.StringValue: ...
        def __init__(
            self,
            *,
            notification_sound_pack_id: _wrappers_pb2.StringValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_notification_sound_pack_id", b"_notification_sound_pack_id", "notification_sound_pack_id", b"notification_sound_pack_id"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_notification_sound_pack_id", b"_notification_sound_pack_id", "notification_sound_pack_id", b"notification_sound_pack_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__notification_sound_pack_id: _TypeAlias = _typing.Literal["notification_sound_pack_id"]  # noqa: Y015
        _WhichOneofArgType__notification_sound_pack_id: _TypeAlias = _typing.Literal["_notification_sound_pack_id", b"_notification_sound_pack_id"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__notification_sound_pack_id) -> _WhichOneofReturnType__notification_sound_pack_id | None: ...

    @_typing.final
    class ChannelSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COLLAPSED_IN_INBOX_FIELD_NUMBER: _builtins.int
        ICON_EMOJI_FIELD_NUMBER: _builtins.int
        CUSTOM_NOTIFICATION_SOUND_CONFIG_FIELD_NUMBER: _builtins.int
        collapsed_in_inbox: _builtins.bool
        @_builtins.property
        def icon_emoji(self) -> Global___PreloadedUserSettings.ChannelIconEmoji: ...
        @_builtins.property
        def custom_notification_sound_config(self) -> Global___PreloadedUserSettings.CustomNotificationSoundConfig: ...
        def __init__(
            self,
            *,
            collapsed_in_inbox: _builtins.bool = ...,
            icon_emoji: Global___PreloadedUserSettings.ChannelIconEmoji | None = ...,
            custom_notification_sound_config: Global___PreloadedUserSettings.CustomNotificationSoundConfig | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_custom_notification_sound_config", b"_custom_notification_sound_config", "_icon_emoji", b"_icon_emoji", "custom_notification_sound_config", b"custom_notification_sound_config", "icon_emoji", b"icon_emoji"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_custom_notification_sound_config", b"_custom_notification_sound_config", "_icon_emoji", b"_icon_emoji", "collapsed_in_inbox", b"collapsed_in_inbox", "custom_notification_sound_config", b"custom_notification_sound_config", "icon_emoji", b"icon_emoji"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__custom_notification_sound_config: _TypeAlias = _typing.Literal["custom_notification_sound_config"]  # noqa: Y015
        _WhichOneofArgType__custom_notification_sound_config: _TypeAlias = _typing.Literal["_custom_notification_sound_config", b"_custom_notification_sound_config"]  # noqa: Y015
        _WhichOneofReturnType__icon_emoji: _TypeAlias = _typing.Literal["icon_emoji"]  # noqa: Y015
        _WhichOneofArgType__icon_emoji: _TypeAlias = _typing.Literal["_icon_emoji", b"_icon_emoji"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__custom_notification_sound_config) -> _WhichOneofReturnType__custom_notification_sound_config | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__icon_emoji) -> _WhichOneofReturnType__icon_emoji | None: ...

    @_typing.final
    class CustomCallSound(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        SOUND_ID_FIELD_NUMBER: _builtins.int
        GUILD_ID_FIELD_NUMBER: _builtins.int
        sound_id: _builtins.int
        guild_id: _builtins.int
        def __init__(
            self,
            *,
            sound_id: _builtins.int = ...,
            guild_id: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["guild_id", b"guild_id", "sound_id", b"sound_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class ChannelListSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LAYOUT_FIELD_NUMBER: _builtins.int
        MESSAGE_PREVIEWS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def layout(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def message_previews(self) -> _wrappers_pb2.StringValue: ...
        def __init__(
            self,
            *,
            layout: _wrappers_pb2.StringValue | None = ...,
            message_previews: _wrappers_pb2.StringValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_layout", b"_layout", "_message_previews", b"_message_previews", "layout", b"layout", "message_previews", b"message_previews"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_layout", b"_layout", "_message_previews", b"_message_previews", "layout", b"layout", "message_previews", b"message_previews"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__layout: _TypeAlias = _typing.Literal["layout"]  # noqa: Y015
        _WhichOneofArgType__layout: _TypeAlias = _typing.Literal["_layout", b"_layout"]  # noqa: Y015
        _WhichOneofReturnType__message_previews: _TypeAlias = _typing.Literal["message_previews"]  # noqa: Y015
        _WhichOneofArgType__message_previews: _TypeAlias = _typing.Literal["_message_previews", b"_message_previews"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__layout) -> _WhichOneofReturnType__layout | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__message_previews) -> _WhichOneofReturnType__message_previews | None: ...

    @_typing.final
    class GuildDismissibleContentState(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        DISMISSED_FIELD_NUMBER: _builtins.int
        LAST_DISMISSED_VERSION_FIELD_NUMBER: _builtins.int
        LAST_DISMISSED_AT_MS_FIELD_NUMBER: _builtins.int
        LAST_DISMISSED_OBJECT_ID_FIELD_NUMBER: _builtins.int
        NUM_TIMES_DISMISSED_FIELD_NUMBER: _builtins.int
        dismissed: _builtins.bool
        last_dismissed_version: _builtins.int
        last_dismissed_at_ms: _builtins.int
        last_dismissed_object_id: _builtins.int
        num_times_dismissed: _builtins.int
        def __init__(
            self,
            *,
            dismissed: _builtins.bool = ...,
            last_dismissed_version: _builtins.int = ...,
            last_dismissed_at_ms: _builtins.int = ...,
            last_dismissed_object_id: _builtins.int = ...,
            num_times_dismissed: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["dismissed", b"dismissed", "last_dismissed_at_ms", b"last_dismissed_at_ms", "last_dismissed_object_id", b"last_dismissed_object_id", "last_dismissed_version", b"last_dismissed_version", "num_times_dismissed", b"num_times_dismissed"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GuildSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class ChannelsEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___PreloadedUserSettings.ChannelSettings: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___PreloadedUserSettings.ChannelSettings | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        @_typing.final
        class GuildDismissibleContentStatesEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___PreloadedUserSettings.GuildDismissibleContentState: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___PreloadedUserSettings.GuildDismissibleContentState | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        CHANNELS_FIELD_NUMBER: _builtins.int
        HUB_PROGRESS_FIELD_NUMBER: _builtins.int
        GUILD_ONBOARDING_PROGRESS_FIELD_NUMBER: _builtins.int
        GUILD_RECENTS_DISMISSED_AT_FIELD_NUMBER: _builtins.int
        DISMISSED_GUILD_CONTENT_FIELD_NUMBER: _builtins.int
        JOIN_SOUND_FIELD_NUMBER: _builtins.int
        MOBILE_REDESIGN_CHANNEL_LIST_SETTINGS_FIELD_NUMBER: _builtins.int
        DISABLE_RAID_ALERT_PUSH_FIELD_NUMBER: _builtins.int
        DISABLE_RAID_ALERT_NAG_FIELD_NUMBER: _builtins.int
        CUSTOM_NOTIFICATION_SOUND_CONFIG_FIELD_NUMBER: _builtins.int
        LEADERBOARDS_DISABLED_FIELD_NUMBER: _builtins.int
        GUILD_DISMISSIBLE_CONTENT_STATES_FIELD_NUMBER: _builtins.int
        hub_progress: _builtins.int
        guild_onboarding_progress: _builtins.int
        dismissed_guild_content: _builtins.bytes
        disable_raid_alert_push: _builtins.bool
        disable_raid_alert_nag: _builtins.bool
        leaderboards_disabled: _builtins.bool
        @_builtins.property
        def channels(self) -> _containers.MessageMap[_builtins.int, Global___PreloadedUserSettings.ChannelSettings]: ...
        @_builtins.property
        def guild_recents_dismissed_at(self) -> _timestamp_pb2.Timestamp: ...
        @_builtins.property
        def join_sound(self) -> Global___PreloadedUserSettings.CustomCallSound: ...
        @_builtins.property
        def mobile_redesign_channel_list_settings(self) -> Global___PreloadedUserSettings.ChannelListSettings: ...
        @_builtins.property
        def custom_notification_sound_config(self) -> Global___PreloadedUserSettings.CustomNotificationSoundConfig: ...
        @_builtins.property
        def guild_dismissible_content_states(self) -> _containers.MessageMap[_builtins.int, Global___PreloadedUserSettings.GuildDismissibleContentState]: ...
        def __init__(
            self,
            *,
            channels: _abc.Mapping[_builtins.int, Global___PreloadedUserSettings.ChannelSettings] | None = ...,
            hub_progress: _builtins.int = ...,
            guild_onboarding_progress: _builtins.int = ...,
            guild_recents_dismissed_at: _timestamp_pb2.Timestamp | None = ...,
            dismissed_guild_content: _builtins.bytes = ...,
            join_sound: Global___PreloadedUserSettings.CustomCallSound | None = ...,
            mobile_redesign_channel_list_settings: Global___PreloadedUserSettings.ChannelListSettings | None = ...,
            disable_raid_alert_push: _builtins.bool = ...,
            disable_raid_alert_nag: _builtins.bool = ...,
            custom_notification_sound_config: Global___PreloadedUserSettings.CustomNotificationSoundConfig | None = ...,
            leaderboards_disabled: _builtins.bool = ...,
            guild_dismissible_content_states: _abc.Mapping[_builtins.int, Global___PreloadedUserSettings.GuildDismissibleContentState] | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_custom_notification_sound_config", b"_custom_notification_sound_config", "_guild_recents_dismissed_at", b"_guild_recents_dismissed_at", "_join_sound", b"_join_sound", "_mobile_redesign_channel_list_settings", b"_mobile_redesign_channel_list_settings", "custom_notification_sound_config", b"custom_notification_sound_config", "guild_recents_dismissed_at", b"guild_recents_dismissed_at", "join_sound", b"join_sound", "mobile_redesign_channel_list_settings", b"mobile_redesign_channel_list_settings"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_custom_notification_sound_config", b"_custom_notification_sound_config", "_guild_recents_dismissed_at", b"_guild_recents_dismissed_at", "_join_sound", b"_join_sound", "_mobile_redesign_channel_list_settings", b"_mobile_redesign_channel_list_settings", "channels", b"channels", "custom_notification_sound_config", b"custom_notification_sound_config", "disable_raid_alert_nag", b"disable_raid_alert_nag", "disable_raid_alert_push", b"disable_raid_alert_push", "dismissed_guild_content", b"dismissed_guild_content", "guild_dismissible_content_states", b"guild_dismissible_content_states", "guild_onboarding_progress", b"guild_onboarding_progress", "guild_recents_dismissed_at", b"guild_recents_dismissed_at", "hub_progress", b"hub_progress", "join_sound", b"join_sound", "leaderboards_disabled", b"leaderboards_disabled", "mobile_redesign_channel_list_settings", b"mobile_redesign_channel_list_settings"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__custom_notification_sound_config: _TypeAlias = _typing.Literal["custom_notification_sound_config"]  # noqa: Y015
        _WhichOneofArgType__custom_notification_sound_config: _TypeAlias = _typing.Literal["_custom_notification_sound_config", b"_custom_notification_sound_config"]  # noqa: Y015
        _WhichOneofReturnType__guild_recents_dismissed_at: _TypeAlias = _typing.Literal["guild_recents_dismissed_at"]  # noqa: Y015
        _WhichOneofArgType__guild_recents_dismissed_at: _TypeAlias = _typing.Literal["_guild_recents_dismissed_at", b"_guild_recents_dismissed_at"]  # noqa: Y015
        _WhichOneofReturnType__join_sound: _TypeAlias = _typing.Literal["join_sound"]  # noqa: Y015
        _WhichOneofArgType__join_sound: _TypeAlias = _typing.Literal["_join_sound", b"_join_sound"]  # noqa: Y015
        _WhichOneofReturnType__mobile_redesign_channel_list_settings: _TypeAlias = _typing.Literal["mobile_redesign_channel_list_settings"]  # noqa: Y015
        _WhichOneofArgType__mobile_redesign_channel_list_settings: _TypeAlias = _typing.Literal["_mobile_redesign_channel_list_settings", b"_mobile_redesign_channel_list_settings"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__custom_notification_sound_config) -> _WhichOneofReturnType__custom_notification_sound_config | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__guild_recents_dismissed_at) -> _WhichOneofReturnType__guild_recents_dismissed_at | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__join_sound) -> _WhichOneofReturnType__join_sound | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__mobile_redesign_channel_list_settings) -> _WhichOneofReturnType__mobile_redesign_channel_list_settings | None: ...

    @_typing.final
    class AllGuildSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class GuildsEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___PreloadedUserSettings.GuildSettings: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___PreloadedUserSettings.GuildSettings | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        GUILDS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def guilds(self) -> _containers.MessageMap[_builtins.int, Global___PreloadedUserSettings.GuildSettings]: ...
        def __init__(
            self,
            *,
            guilds: _abc.Mapping[_builtins.int, Global___PreloadedUserSettings.GuildSettings] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["guilds", b"guilds"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class RecurringDismissibleContentState(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LAST_DISMISSED_VERSION_FIELD_NUMBER: _builtins.int
        LAST_DISMISSED_AT_MS_FIELD_NUMBER: _builtins.int
        LAST_DISMISSED_OBJECT_ID_FIELD_NUMBER: _builtins.int
        NUM_TIMES_DISMISSED_FIELD_NUMBER: _builtins.int
        last_dismissed_version: _builtins.int
        last_dismissed_at_ms: _builtins.int
        last_dismissed_object_id: _builtins.int
        num_times_dismissed: _builtins.int
        def __init__(
            self,
            *,
            last_dismissed_version: _builtins.int = ...,
            last_dismissed_at_ms: _builtins.int = ...,
            last_dismissed_object_id: _builtins.int = ...,
            num_times_dismissed: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["last_dismissed_at_ms", b"last_dismissed_at_ms", "last_dismissed_object_id", b"last_dismissed_object_id", "last_dismissed_version", b"last_dismissed_version", "num_times_dismissed", b"num_times_dismissed"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class UserContentSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class RecurringDismissibleContentStatesEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___PreloadedUserSettings.RecurringDismissibleContentState: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___PreloadedUserSettings.RecurringDismissibleContentState | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        DISMISSED_CONTENTS_FIELD_NUMBER: _builtins.int
        LAST_DISMISSED_OUTBOUND_PROMOTION_START_DATE_FIELD_NUMBER: _builtins.int
        PREMIUM_TIER_0_MODAL_DISMISSED_AT_FIELD_NUMBER: _builtins.int
        GUILD_ONBOARDING_UPSELL_DISMISSED_AT_FIELD_NUMBER: _builtins.int
        SAFETY_USER_SENTIMENT_NOTICE_DISMISSED_AT_FIELD_NUMBER: _builtins.int
        LAST_RECEIVED_CHANGELOG_ID_FIELD_NUMBER: _builtins.int
        RECURRING_DISMISSIBLE_CONTENT_STATES_FIELD_NUMBER: _builtins.int
        dismissed_contents: _builtins.bytes
        last_received_changelog_id: _builtins.int
        @_builtins.property
        def last_dismissed_outbound_promotion_start_date(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def premium_tier_0_modal_dismissed_at(self) -> _timestamp_pb2.Timestamp: ...
        @_builtins.property
        def guild_onboarding_upsell_dismissed_at(self) -> _timestamp_pb2.Timestamp: ...
        @_builtins.property
        def safety_user_sentiment_notice_dismissed_at(self) -> _timestamp_pb2.Timestamp: ...
        @_builtins.property
        def recurring_dismissible_content_states(self) -> _containers.MessageMap[_builtins.int, Global___PreloadedUserSettings.RecurringDismissibleContentState]: ...
        def __init__(
            self,
            *,
            dismissed_contents: _builtins.bytes = ...,
            last_dismissed_outbound_promotion_start_date: _wrappers_pb2.StringValue | None = ...,
            premium_tier_0_modal_dismissed_at: _timestamp_pb2.Timestamp | None = ...,
            guild_onboarding_upsell_dismissed_at: _timestamp_pb2.Timestamp | None = ...,
            safety_user_sentiment_notice_dismissed_at: _timestamp_pb2.Timestamp | None = ...,
            last_received_changelog_id: _builtins.int = ...,
            recurring_dismissible_content_states: _abc.Mapping[_builtins.int, Global___PreloadedUserSettings.RecurringDismissibleContentState] | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_guild_onboarding_upsell_dismissed_at", b"_guild_onboarding_upsell_dismissed_at", "_last_dismissed_outbound_promotion_start_date", b"_last_dismissed_outbound_promotion_start_date", "_premium_tier_0_modal_dismissed_at", b"_premium_tier_0_modal_dismissed_at", "_safety_user_sentiment_notice_dismissed_at", b"_safety_user_sentiment_notice_dismissed_at", "guild_onboarding_upsell_dismissed_at", b"guild_onboarding_upsell_dismissed_at", "last_dismissed_outbound_promotion_start_date", b"last_dismissed_outbound_promotion_start_date", "premium_tier_0_modal_dismissed_at", b"premium_tier_0_modal_dismissed_at", "safety_user_sentiment_notice_dismissed_at", b"safety_user_sentiment_notice_dismissed_at"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_guild_onboarding_upsell_dismissed_at", b"_guild_onboarding_upsell_dismissed_at", "_last_dismissed_outbound_promotion_start_date", b"_last_dismissed_outbound_promotion_start_date", "_premium_tier_0_modal_dismissed_at", b"_premium_tier_0_modal_dismissed_at", "_safety_user_sentiment_notice_dismissed_at", b"_safety_user_sentiment_notice_dismissed_at", "dismissed_contents", b"dismissed_contents", "guild_onboarding_upsell_dismissed_at", b"guild_onboarding_upsell_dismissed_at", "last_dismissed_outbound_promotion_start_date", b"last_dismissed_outbound_promotion_start_date", "last_received_changelog_id", b"last_received_changelog_id", "premium_tier_0_modal_dismissed_at", b"premium_tier_0_modal_dismissed_at", "recurring_dismissible_content_states", b"recurring_dismissible_content_states", "safety_user_sentiment_notice_dismissed_at", b"safety_user_sentiment_notice_dismissed_at"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__guild_onboarding_upsell_dismissed_at: _TypeAlias = _typing.Literal["guild_onboarding_upsell_dismissed_at"]  # noqa: Y015
        _WhichOneofArgType__guild_onboarding_upsell_dismissed_at: _TypeAlias = _typing.Literal["_guild_onboarding_upsell_dismissed_at", b"_guild_onboarding_upsell_dismissed_at"]  # noqa: Y015
        _WhichOneofReturnType__last_dismissed_outbound_promotion_start_date: _TypeAlias = _typing.Literal["last_dismissed_outbound_promotion_start_date"]  # noqa: Y015
        _WhichOneofArgType__last_dismissed_outbound_promotion_start_date: _TypeAlias = _typing.Literal["_last_dismissed_outbound_promotion_start_date", b"_last_dismissed_outbound_promotion_start_date"]  # noqa: Y015
        _WhichOneofReturnType__premium_tier_0_modal_dismissed_at: _TypeAlias = _typing.Literal["premium_tier_0_modal_dismissed_at"]  # noqa: Y015
        _WhichOneofArgType__premium_tier_0_modal_dismissed_at: _TypeAlias = _typing.Literal["_premium_tier_0_modal_dismissed_at", b"_premium_tier_0_modal_dismissed_at"]  # noqa: Y015
        _WhichOneofReturnType__safety_user_sentiment_notice_dismissed_at: _TypeAlias = _typing.Literal["safety_user_sentiment_notice_dismissed_at"]  # noqa: Y015
        _WhichOneofArgType__safety_user_sentiment_notice_dismissed_at: _TypeAlias = _typing.Literal["_safety_user_sentiment_notice_dismissed_at", b"_safety_user_sentiment_notice_dismissed_at"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__guild_onboarding_upsell_dismissed_at) -> _WhichOneofReturnType__guild_onboarding_upsell_dismissed_at | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__last_dismissed_outbound_promotion_start_date) -> _WhichOneofReturnType__last_dismissed_outbound_promotion_start_date | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__premium_tier_0_modal_dismissed_at) -> _WhichOneofReturnType__premium_tier_0_modal_dismissed_at | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__safety_user_sentiment_notice_dismissed_at) -> _WhichOneofReturnType__safety_user_sentiment_notice_dismissed_at | None: ...

    @_typing.final
    class VideoFilterBackgroundBlur(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        USE_BLUR_FIELD_NUMBER: _builtins.int
        use_blur: _builtins.bool
        def __init__(
            self,
            *,
            use_blur: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["use_blur", b"use_blur"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class VideoFilterAsset(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ID_FIELD_NUMBER: _builtins.int
        ASSET_HASH_FIELD_NUMBER: _builtins.int
        id: _builtins.int
        asset_hash: _builtins.str
        def __init__(
            self,
            *,
            id: _builtins.int = ...,
            asset_hash: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["asset_hash", b"asset_hash", "id", b"id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SoundboardSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        VOLUME_FIELD_NUMBER: _builtins.int
        volume: _builtins.float
        def __init__(
            self,
            *,
            volume: _builtins.float = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["volume", b"volume"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class VoiceAndVideoSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BLUR_FIELD_NUMBER: _builtins.int
        PRESET_OPTION_FIELD_NUMBER: _builtins.int
        CUSTOM_ASSET_FIELD_NUMBER: _builtins.int
        ALWAYS_PREVIEW_VIDEO_FIELD_NUMBER: _builtins.int
        AFK_TIMEOUT_FIELD_NUMBER: _builtins.int
        STREAM_NOTIFICATIONS_ENABLED_FIELD_NUMBER: _builtins.int
        NATIVE_PHONE_INTEGRATION_ENABLED_FIELD_NUMBER: _builtins.int
        SOUNDBOARD_SETTINGS_FIELD_NUMBER: _builtins.int
        DISABLE_STREAM_PREVIEWS_FIELD_NUMBER: _builtins.int
        SOUNDMOJI_VOLUME_FIELD_NUMBER: _builtins.int
        preset_option: _builtins.int
        @_builtins.property
        def blur(self) -> Global___PreloadedUserSettings.VideoFilterBackgroundBlur: ...
        @_builtins.property
        def custom_asset(self) -> Global___PreloadedUserSettings.VideoFilterAsset: ...
        @_builtins.property
        def always_preview_video(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def afk_timeout(self) -> _wrappers_pb2.UInt32Value: ...
        @_builtins.property
        def stream_notifications_enabled(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def native_phone_integration_enabled(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def soundboard_settings(self) -> Global___PreloadedUserSettings.SoundboardSettings: ...
        @_builtins.property
        def disable_stream_previews(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def soundmoji_volume(self) -> _wrappers_pb2.FloatValue: ...
        def __init__(
            self,
            *,
            blur: Global___PreloadedUserSettings.VideoFilterBackgroundBlur | None = ...,
            preset_option: _builtins.int = ...,
            custom_asset: Global___PreloadedUserSettings.VideoFilterAsset | None = ...,
            always_preview_video: _wrappers_pb2.BoolValue | None = ...,
            afk_timeout: _wrappers_pb2.UInt32Value | None = ...,
            stream_notifications_enabled: _wrappers_pb2.BoolValue | None = ...,
            native_phone_integration_enabled: _wrappers_pb2.BoolValue | None = ...,
            soundboard_settings: Global___PreloadedUserSettings.SoundboardSettings | None = ...,
            disable_stream_previews: _wrappers_pb2.BoolValue | None = ...,
            soundmoji_volume: _wrappers_pb2.FloatValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_afk_timeout", b"_afk_timeout", "_always_preview_video", b"_always_preview_video", "_disable_stream_previews", b"_disable_stream_previews", "_native_phone_integration_enabled", b"_native_phone_integration_enabled", "_soundboard_settings", b"_soundboard_settings", "_soundmoji_volume", b"_soundmoji_volume", "_stream_notifications_enabled", b"_stream_notifications_enabled", "afk_timeout", b"afk_timeout", "always_preview_video", b"always_preview_video", "blur", b"blur", "custom_asset", b"custom_asset", "disable_stream_previews", b"disable_stream_previews", "native_phone_integration_enabled", b"native_phone_integration_enabled", "preset_option", b"preset_option", "soundboard_settings", b"soundboard_settings", "soundmoji_volume", b"soundmoji_volume", "stream_notifications_enabled", b"stream_notifications_enabled", "video_background_filter_desktop", b"video_background_filter_desktop"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_afk_timeout", b"_afk_timeout", "_always_preview_video", b"_always_preview_video", "_disable_stream_previews", b"_disable_stream_previews", "_native_phone_integration_enabled", b"_native_phone_integration_enabled", "_soundboard_settings", b"_soundboard_settings", "_soundmoji_volume", b"_soundmoji_volume", "_stream_notifications_enabled", b"_stream_notifications_enabled", "afk_timeout", b"afk_timeout", "always_preview_video", b"always_preview_video", "blur", b"blur", "custom_asset", b"custom_asset", "disable_stream_previews", b"disable_stream_previews", "native_phone_integration_enabled", b"native_phone_integration_enabled", "preset_option", b"preset_option", "soundboard_settings", b"soundboard_settings", "soundmoji_volume", b"soundmoji_volume", "stream_notifications_enabled", b"stream_notifications_enabled", "video_background_filter_desktop", b"video_background_filter_desktop"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__afk_timeout: _TypeAlias = _typing.Literal["afk_timeout"]  # noqa: Y015
        _WhichOneofArgType__afk_timeout: _TypeAlias = _typing.Literal["_afk_timeout", b"_afk_timeout"]  # noqa: Y015
        _WhichOneofReturnType__always_preview_video: _TypeAlias = _typing.Literal["always_preview_video"]  # noqa: Y015
        _WhichOneofArgType__always_preview_video: _TypeAlias = _typing.Literal["_always_preview_video", b"_always_preview_video"]  # noqa: Y015
        _WhichOneofReturnType__disable_stream_previews: _TypeAlias = _typing.Literal["disable_stream_previews"]  # noqa: Y015
        _WhichOneofArgType__disable_stream_previews: _TypeAlias = _typing.Literal["_disable_stream_previews", b"_disable_stream_previews"]  # noqa: Y015
        _WhichOneofReturnType__native_phone_integration_enabled: _TypeAlias = _typing.Literal["native_phone_integration_enabled"]  # noqa: Y015
        _WhichOneofArgType__native_phone_integration_enabled: _TypeAlias = _typing.Literal["_native_phone_integration_enabled", b"_native_phone_integration_enabled"]  # noqa: Y015
        _WhichOneofReturnType__soundboard_settings: _TypeAlias = _typing.Literal["soundboard_settings"]  # noqa: Y015
        _WhichOneofArgType__soundboard_settings: _TypeAlias = _typing.Literal["_soundboard_settings", b"_soundboard_settings"]  # noqa: Y015
        _WhichOneofReturnType__soundmoji_volume: _TypeAlias = _typing.Literal["soundmoji_volume"]  # noqa: Y015
        _WhichOneofArgType__soundmoji_volume: _TypeAlias = _typing.Literal["_soundmoji_volume", b"_soundmoji_volume"]  # noqa: Y015
        _WhichOneofReturnType__stream_notifications_enabled: _TypeAlias = _typing.Literal["stream_notifications_enabled"]  # noqa: Y015
        _WhichOneofArgType__stream_notifications_enabled: _TypeAlias = _typing.Literal["_stream_notifications_enabled", b"_stream_notifications_enabled"]  # noqa: Y015
        _WhichOneofReturnType_video_background_filter_desktop: _TypeAlias = _typing.Literal["blur", "preset_option", "custom_asset"]  # noqa: Y015
        _WhichOneofArgType_video_background_filter_desktop: _TypeAlias = _typing.Literal["video_background_filter_desktop", b"video_background_filter_desktop"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__afk_timeout) -> _WhichOneofReturnType__afk_timeout | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__always_preview_video) -> _WhichOneofReturnType__always_preview_video | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__disable_stream_previews) -> _WhichOneofReturnType__disable_stream_previews | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__native_phone_integration_enabled) -> _WhichOneofReturnType__native_phone_integration_enabled | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__soundboard_settings) -> _WhichOneofReturnType__soundboard_settings | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__soundmoji_volume) -> _WhichOneofReturnType__soundmoji_volume | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__stream_notifications_enabled) -> _WhichOneofReturnType__stream_notifications_enabled | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType_video_background_filter_desktop) -> _WhichOneofReturnType_video_background_filter_desktop | None: ...

    @_typing.final
    class ExplicitContentSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        EXPLICIT_CONTENT_GUILDS_FIELD_NUMBER: _builtins.int
        EXPLICIT_CONTENT_FRIEND_DM_FIELD_NUMBER: _builtins.int
        EXPLICIT_CONTENT_NON_FRIEND_DM_FIELD_NUMBER: _builtins.int
        explicit_content_guilds: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType
        explicit_content_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType
        explicit_content_non_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType
        def __init__(
            self,
            *,
            explicit_content_guilds: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType = ...,
            explicit_content_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType = ...,
            explicit_content_non_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["explicit_content_friend_dm", b"explicit_content_friend_dm", "explicit_content_guilds", b"explicit_content_guilds", "explicit_content_non_friend_dm", b"explicit_content_non_friend_dm"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class KeywordFilterSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        PROFANITY_FIELD_NUMBER: _builtins.int
        SEXUAL_CONTENT_FIELD_NUMBER: _builtins.int
        SLURS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def profanity(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def sexual_content(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def slurs(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            profanity: _wrappers_pb2.BoolValue | None = ...,
            sexual_content: _wrappers_pb2.BoolValue | None = ...,
            slurs: _wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_profanity", b"_profanity", "_sexual_content", b"_sexual_content", "_slurs", b"_slurs", "profanity", b"profanity", "sexual_content", b"sexual_content", "slurs", b"slurs"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_profanity", b"_profanity", "_sexual_content", b"_sexual_content", "_slurs", b"_slurs", "profanity", b"profanity", "sexual_content", b"sexual_content", "slurs", b"slurs"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__profanity: _TypeAlias = _typing.Literal["profanity"]  # noqa: Y015
        _WhichOneofArgType__profanity: _TypeAlias = _typing.Literal["_profanity", b"_profanity"]  # noqa: Y015
        _WhichOneofReturnType__sexual_content: _TypeAlias = _typing.Literal["sexual_content"]  # noqa: Y015
        _WhichOneofArgType__sexual_content: _TypeAlias = _typing.Literal["_sexual_content", b"_sexual_content"]  # noqa: Y015
        _WhichOneofReturnType__slurs: _TypeAlias = _typing.Literal["slurs"]  # noqa: Y015
        _WhichOneofArgType__slurs: _TypeAlias = _typing.Literal["_slurs", b"_slurs"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__profanity) -> _WhichOneofReturnType__profanity | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__sexual_content) -> _WhichOneofReturnType__sexual_content | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__slurs) -> _WhichOneofReturnType__slurs | None: ...

    @_typing.final
    class GoreContentSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        GORE_CONTENT_GUILDS_FIELD_NUMBER: _builtins.int
        GORE_CONTENT_FRIEND_DM_FIELD_NUMBER: _builtins.int
        GORE_CONTENT_NON_FRIEND_DM_FIELD_NUMBER: _builtins.int
        gore_content_guilds: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType
        gore_content_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType
        gore_content_non_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType
        def __init__(
            self,
            *,
            gore_content_guilds: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType = ...,
            gore_content_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType = ...,
            gore_content_non_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["gore_content_friend_dm", b"gore_content_friend_dm", "gore_content_guilds", b"gore_content_guilds", "gore_content_non_friend_dm", b"gore_content_non_friend_dm"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class DefaultReactionEmoji(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        EMOJI_ID_FIELD_NUMBER: _builtins.int
        EMOJI_NAME_FIELD_NUMBER: _builtins.int
        ANIMATED_FIELD_NUMBER: _builtins.int
        DISABLE_DOUBLE_TAP_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def emoji_id(self) -> _wrappers_pb2.UInt64Value: ...
        @_builtins.property
        def emoji_name(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def animated(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def disable_double_tap(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            emoji_id: _wrappers_pb2.UInt64Value | None = ...,
            emoji_name: _wrappers_pb2.StringValue | None = ...,
            animated: _wrappers_pb2.BoolValue | None = ...,
            disable_double_tap: _wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_animated", b"_animated", "_disable_double_tap", b"_disable_double_tap", "_emoji_id", b"_emoji_id", "_emoji_name", b"_emoji_name", "animated", b"animated", "disable_double_tap", b"disable_double_tap", "emoji_id", b"emoji_id", "emoji_name", b"emoji_name"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_animated", b"_animated", "_disable_double_tap", b"_disable_double_tap", "_emoji_id", b"_emoji_id", "_emoji_name", b"_emoji_name", "animated", b"animated", "disable_double_tap", b"disable_double_tap", "emoji_id", b"emoji_id", "emoji_name", b"emoji_name"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__animated: _TypeAlias = _typing.Literal["animated"]  # noqa: Y015
        _WhichOneofArgType__animated: _TypeAlias = _typing.Literal["_animated", b"_animated"]  # noqa: Y015
        _WhichOneofReturnType__disable_double_tap: _TypeAlias = _typing.Literal["disable_double_tap"]  # noqa: Y015
        _WhichOneofArgType__disable_double_tap: _TypeAlias = _typing.Literal["_disable_double_tap", b"_disable_double_tap"]  # noqa: Y015
        _WhichOneofReturnType__emoji_id: _TypeAlias = _typing.Literal["emoji_id"]  # noqa: Y015
        _WhichOneofArgType__emoji_id: _TypeAlias = _typing.Literal["_emoji_id", b"_emoji_id"]  # noqa: Y015
        _WhichOneofReturnType__emoji_name: _TypeAlias = _typing.Literal["emoji_name"]  # noqa: Y015
        _WhichOneofArgType__emoji_name: _TypeAlias = _typing.Literal["_emoji_name", b"_emoji_name"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__animated) -> _WhichOneofReturnType__animated | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__disable_double_tap) -> _WhichOneofReturnType__disable_double_tap | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__emoji_id) -> _WhichOneofReturnType__emoji_id | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__emoji_name) -> _WhichOneofReturnType__emoji_name | None: ...

    @_typing.final
    class SelfHarmContentSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        SELF_HARM_CONTENT_GUILDS_FIELD_NUMBER: _builtins.int
        SELF_HARM_CONTENT_FRIEND_DM_FIELD_NUMBER: _builtins.int
        SELF_HARM_CONTENT_NON_FRIEND_DM_FIELD_NUMBER: _builtins.int
        self_harm_content_guilds: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType
        self_harm_content_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType
        self_harm_content_non_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType
        def __init__(
            self,
            *,
            self_harm_content_guilds: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType = ...,
            self_harm_content_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType = ...,
            self_harm_content_non_friend_dm: Global___PreloadedUserSettings.ExplicitContentRedaction.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["self_harm_content_friend_dm", b"self_harm_content_friend_dm", "self_harm_content_guilds", b"self_harm_content_guilds", "self_harm_content_non_friend_dm", b"self_harm_content_non_friend_dm"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class TextAndImagesSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        DIVERSITY_SURROGATE_FIELD_NUMBER: _builtins.int
        USE_RICH_CHAT_INPUT_FIELD_NUMBER: _builtins.int
        USE_THREAD_SIDEBAR_FIELD_NUMBER: _builtins.int
        RENDER_SPOILERS_FIELD_NUMBER: _builtins.int
        EMOJI_PICKER_COLLAPSED_SECTIONS_FIELD_NUMBER: _builtins.int
        STICKER_PICKER_COLLAPSED_SECTIONS_FIELD_NUMBER: _builtins.int
        VIEW_IMAGE_DESCRIPTIONS_FIELD_NUMBER: _builtins.int
        SHOW_COMMAND_SUGGESTIONS_FIELD_NUMBER: _builtins.int
        INLINE_ATTACHMENT_MEDIA_FIELD_NUMBER: _builtins.int
        INLINE_EMBED_MEDIA_FIELD_NUMBER: _builtins.int
        GIF_AUTO_PLAY_FIELD_NUMBER: _builtins.int
        RENDER_EMBEDS_FIELD_NUMBER: _builtins.int
        RENDER_REACTIONS_FIELD_NUMBER: _builtins.int
        ANIMATE_EMOJI_FIELD_NUMBER: _builtins.int
        ANIMATE_STICKERS_FIELD_NUMBER: _builtins.int
        ENABLE_TTS_COMMAND_FIELD_NUMBER: _builtins.int
        MESSAGE_DISPLAY_COMPACT_FIELD_NUMBER: _builtins.int
        EXPLICIT_CONTENT_FILTER_FIELD_NUMBER: _builtins.int
        VIEW_NSFW_GUILDS_FIELD_NUMBER: _builtins.int
        CONVERT_EMOTICONS_FIELD_NUMBER: _builtins.int
        EXPRESSION_SUGGESTIONS_ENABLED_FIELD_NUMBER: _builtins.int
        VIEW_NSFW_COMMANDS_FIELD_NUMBER: _builtins.int
        USE_LEGACY_CHAT_INPUT_FIELD_NUMBER: _builtins.int
        SOUNDBOARD_PICKER_COLLAPSED_SECTIONS_FIELD_NUMBER: _builtins.int
        DM_SPAM_FILTER_FIELD_NUMBER: _builtins.int
        DM_SPAM_FILTER_V2_FIELD_NUMBER: _builtins.int
        INCLUDE_STICKERS_IN_AUTOCOMPLETE_FIELD_NUMBER: _builtins.int
        EXPLICIT_CONTENT_SETTINGS_FIELD_NUMBER: _builtins.int
        KEYWORD_FILTER_SETTINGS_FIELD_NUMBER: _builtins.int
        INCLUDE_SOUNDMOJI_IN_AUTOCOMPLETE_FIELD_NUMBER: _builtins.int
        GORE_CONTENT_SETTINGS_FIELD_NUMBER: _builtins.int
        DEFAULT_REACTION_EMOJI_FIELD_NUMBER: _builtins.int
        SHOW_MENTION_SUGGESTIONS_FIELD_NUMBER: _builtins.int
        SELF_HARM_CONTENT_SETTINGS_FIELD_NUMBER: _builtins.int
        IS_CROSS_DM_SEARCH_ENABLED_FIELD_NUMBER: _builtins.int
        dm_spam_filter_v2: Global___PreloadedUserSettings.DmSpamFilterV2.ValueType
        @_builtins.property
        def diversity_surrogate(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def use_rich_chat_input(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def use_thread_sidebar(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def render_spoilers(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def emoji_picker_collapsed_sections(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
        @_builtins.property
        def sticker_picker_collapsed_sections(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
        @_builtins.property
        def view_image_descriptions(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def show_command_suggestions(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def inline_attachment_media(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def inline_embed_media(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def gif_auto_play(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def render_embeds(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def render_reactions(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def animate_emoji(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def animate_stickers(self) -> _wrappers_pb2.UInt32Value: ...
        @_builtins.property
        def enable_tts_command(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def message_display_compact(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def explicit_content_filter(self) -> _wrappers_pb2.UInt32Value: ...
        @_builtins.property
        def view_nsfw_guilds(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def convert_emoticons(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def expression_suggestions_enabled(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def view_nsfw_commands(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def use_legacy_chat_input(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def soundboard_picker_collapsed_sections(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
        @_builtins.property
        def dm_spam_filter(self) -> _wrappers_pb2.UInt32Value: ...
        @_builtins.property
        def include_stickers_in_autocomplete(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def explicit_content_settings(self) -> Global___PreloadedUserSettings.ExplicitContentSettings: ...
        @_builtins.property
        def keyword_filter_settings(self) -> Global___PreloadedUserSettings.KeywordFilterSettings: ...
        @_builtins.property
        def include_soundmoji_in_autocomplete(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def gore_content_settings(self) -> Global___PreloadedUserSettings.GoreContentSettings: ...
        @_builtins.property
        def default_reaction_emoji(self) -> Global___PreloadedUserSettings.DefaultReactionEmoji: ...
        @_builtins.property
        def show_mention_suggestions(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def self_harm_content_settings(self) -> Global___PreloadedUserSettings.SelfHarmContentSettings: ...
        @_builtins.property
        def is_cross_dm_search_enabled(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            diversity_surrogate: _wrappers_pb2.StringValue | None = ...,
            use_rich_chat_input: _wrappers_pb2.BoolValue | None = ...,
            use_thread_sidebar: _wrappers_pb2.BoolValue | None = ...,
            render_spoilers: _wrappers_pb2.StringValue | None = ...,
            emoji_picker_collapsed_sections: _abc.Iterable[_builtins.str] | None = ...,
            sticker_picker_collapsed_sections: _abc.Iterable[_builtins.str] | None = ...,
            view_image_descriptions: _wrappers_pb2.BoolValue | None = ...,
            show_command_suggestions: _wrappers_pb2.BoolValue | None = ...,
            inline_attachment_media: _wrappers_pb2.BoolValue | None = ...,
            inline_embed_media: _wrappers_pb2.BoolValue | None = ...,
            gif_auto_play: _wrappers_pb2.BoolValue | None = ...,
            render_embeds: _wrappers_pb2.BoolValue | None = ...,
            render_reactions: _wrappers_pb2.BoolValue | None = ...,
            animate_emoji: _wrappers_pb2.BoolValue | None = ...,
            animate_stickers: _wrappers_pb2.UInt32Value | None = ...,
            enable_tts_command: _wrappers_pb2.BoolValue | None = ...,
            message_display_compact: _wrappers_pb2.BoolValue | None = ...,
            explicit_content_filter: _wrappers_pb2.UInt32Value | None = ...,
            view_nsfw_guilds: _wrappers_pb2.BoolValue | None = ...,
            convert_emoticons: _wrappers_pb2.BoolValue | None = ...,
            expression_suggestions_enabled: _wrappers_pb2.BoolValue | None = ...,
            view_nsfw_commands: _wrappers_pb2.BoolValue | None = ...,
            use_legacy_chat_input: _wrappers_pb2.BoolValue | None = ...,
            soundboard_picker_collapsed_sections: _abc.Iterable[_builtins.str] | None = ...,
            dm_spam_filter: _wrappers_pb2.UInt32Value | None = ...,
            dm_spam_filter_v2: Global___PreloadedUserSettings.DmSpamFilterV2.ValueType = ...,
            include_stickers_in_autocomplete: _wrappers_pb2.BoolValue | None = ...,
            explicit_content_settings: Global___PreloadedUserSettings.ExplicitContentSettings | None = ...,
            keyword_filter_settings: Global___PreloadedUserSettings.KeywordFilterSettings | None = ...,
            include_soundmoji_in_autocomplete: _wrappers_pb2.BoolValue | None = ...,
            gore_content_settings: Global___PreloadedUserSettings.GoreContentSettings | None = ...,
            default_reaction_emoji: Global___PreloadedUserSettings.DefaultReactionEmoji | None = ...,
            show_mention_suggestions: _wrappers_pb2.BoolValue | None = ...,
            self_harm_content_settings: Global___PreloadedUserSettings.SelfHarmContentSettings | None = ...,
            is_cross_dm_search_enabled: _wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_animate_emoji", b"_animate_emoji", "_animate_stickers", b"_animate_stickers", "_convert_emoticons", b"_convert_emoticons", "_default_reaction_emoji", b"_default_reaction_emoji", "_diversity_surrogate", b"_diversity_surrogate", "_dm_spam_filter", b"_dm_spam_filter", "_enable_tts_command", b"_enable_tts_command", "_explicit_content_filter", b"_explicit_content_filter", "_explicit_content_settings", b"_explicit_content_settings", "_expression_suggestions_enabled", b"_expression_suggestions_enabled", "_gif_auto_play", b"_gif_auto_play", "_gore_content_settings", b"_gore_content_settings", "_include_soundmoji_in_autocomplete", b"_include_soundmoji_in_autocomplete", "_include_stickers_in_autocomplete", b"_include_stickers_in_autocomplete", "_inline_attachment_media", b"_inline_attachment_media", "_inline_embed_media", b"_inline_embed_media", "_is_cross_dm_search_enabled", b"_is_cross_dm_search_enabled", "_keyword_filter_settings", b"_keyword_filter_settings", "_message_display_compact", b"_message_display_compact", "_render_embeds", b"_render_embeds", "_render_reactions", b"_render_reactions", "_render_spoilers", b"_render_spoilers", "_self_harm_content_settings", b"_self_harm_content_settings", "_show_command_suggestions", b"_show_command_suggestions", "_show_mention_suggestions", b"_show_mention_suggestions", "_use_legacy_chat_input", b"_use_legacy_chat_input", "_use_rich_chat_input", b"_use_rich_chat_input", "_use_thread_sidebar", b"_use_thread_sidebar", "_view_image_descriptions", b"_view_image_descriptions", "_view_nsfw_commands", b"_view_nsfw_commands", "_view_nsfw_guilds", b"_view_nsfw_guilds", "animate_emoji", b"animate_emoji", "animate_stickers", b"animate_stickers", "convert_emoticons", b"convert_emoticons", "default_reaction_emoji", b"default_reaction_emoji", "diversity_surrogate", b"diversity_surrogate", "dm_spam_filter", b"dm_spam_filter", "enable_tts_command", b"enable_tts_command", "explicit_content_filter", b"explicit_content_filter", "explicit_content_settings", b"explicit_content_settings", "expression_suggestions_enabled", b"expression_suggestions_enabled", "gif_auto_play", b"gif_auto_play", "gore_content_settings", b"gore_content_settings", "include_soundmoji_in_autocomplete", b"include_soundmoji_in_autocomplete", "include_stickers_in_autocomplete", b"include_stickers_in_autocomplete", "inline_attachment_media", b"inline_attachment_media", "inline_embed_media", b"inline_embed_media", "is_cross_dm_search_enabled", b"is_cross_dm_search_enabled", "keyword_filter_settings", b"keyword_filter_settings", "message_display_compact", b"message_display_compact", "render_embeds", b"render_embeds", "render_reactions", b"render_reactions", "render_spoilers", b"render_spoilers", "self_harm_content_settings", b"self_harm_content_settings", "show_command_suggestions", b"show_command_suggestions", "show_mention_suggestions", b"show_mention_suggestions", "use_legacy_chat_input", b"use_legacy_chat_input", "use_rich_chat_input", b"use_rich_chat_input", "use_thread_sidebar", b"use_thread_sidebar", "view_image_descriptions", b"view_image_descriptions", "view_nsfw_commands", b"view_nsfw_commands", "view_nsfw_guilds", b"view_nsfw_guilds"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_animate_emoji", b"_animate_emoji", "_animate_stickers", b"_animate_stickers", "_convert_emoticons", b"_convert_emoticons", "_default_reaction_emoji", b"_default_reaction_emoji", "_diversity_surrogate", b"_diversity_surrogate", "_dm_spam_filter", b"_dm_spam_filter", "_enable_tts_command", b"_enable_tts_command", "_explicit_content_filter", b"_explicit_content_filter", "_explicit_content_settings", b"_explicit_content_settings", "_expression_suggestions_enabled", b"_expression_suggestions_enabled", "_gif_auto_play", b"_gif_auto_play", "_gore_content_settings", b"_gore_content_settings", "_include_soundmoji_in_autocomplete", b"_include_soundmoji_in_autocomplete", "_include_stickers_in_autocomplete", b"_include_stickers_in_autocomplete", "_inline_attachment_media", b"_inline_attachment_media", "_inline_embed_media", b"_inline_embed_media", "_is_cross_dm_search_enabled", b"_is_cross_dm_search_enabled", "_keyword_filter_settings", b"_keyword_filter_settings", "_message_display_compact", b"_message_display_compact", "_render_embeds", b"_render_embeds", "_render_reactions", b"_render_reactions", "_render_spoilers", b"_render_spoilers", "_self_harm_content_settings", b"_self_harm_content_settings", "_show_command_suggestions", b"_show_command_suggestions", "_show_mention_suggestions", b"_show_mention_suggestions", "_use_legacy_chat_input", b"_use_legacy_chat_input", "_use_rich_chat_input", b"_use_rich_chat_input", "_use_thread_sidebar", b"_use_thread_sidebar", "_view_image_descriptions", b"_view_image_descriptions", "_view_nsfw_commands", b"_view_nsfw_commands", "_view_nsfw_guilds", b"_view_nsfw_guilds", "animate_emoji", b"animate_emoji", "animate_stickers", b"animate_stickers", "convert_emoticons", b"convert_emoticons", "default_reaction_emoji", b"default_reaction_emoji", "diversity_surrogate", b"diversity_surrogate", "dm_spam_filter", b"dm_spam_filter", "dm_spam_filter_v2", b"dm_spam_filter_v2", "emoji_picker_collapsed_sections", b"emoji_picker_collapsed_sections", "enable_tts_command", b"enable_tts_command", "explicit_content_filter", b"explicit_content_filter", "explicit_content_settings", b"explicit_content_settings", "expression_suggestions_enabled", b"expression_suggestions_enabled", "gif_auto_play", b"gif_auto_play", "gore_content_settings", b"gore_content_settings", "include_soundmoji_in_autocomplete", b"include_soundmoji_in_autocomplete", "include_stickers_in_autocomplete", b"include_stickers_in_autocomplete", "inline_attachment_media", b"inline_attachment_media", "inline_embed_media", b"inline_embed_media", "is_cross_dm_search_enabled", b"is_cross_dm_search_enabled", "keyword_filter_settings", b"keyword_filter_settings", "message_display_compact", b"message_display_compact", "render_embeds", b"render_embeds", "render_reactions", b"render_reactions", "render_spoilers", b"render_spoilers", "self_harm_content_settings", b"self_harm_content_settings", "show_command_suggestions", b"show_command_suggestions", "show_mention_suggestions", b"show_mention_suggestions", "soundboard_picker_collapsed_sections", b"soundboard_picker_collapsed_sections", "sticker_picker_collapsed_sections", b"sticker_picker_collapsed_sections", "use_legacy_chat_input", b"use_legacy_chat_input", "use_rich_chat_input", b"use_rich_chat_input", "use_thread_sidebar", b"use_thread_sidebar", "view_image_descriptions", b"view_image_descriptions", "view_nsfw_commands", b"view_nsfw_commands", "view_nsfw_guilds", b"view_nsfw_guilds"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__animate_emoji: _TypeAlias = _typing.Literal["animate_emoji"]  # noqa: Y015
        _WhichOneofArgType__animate_emoji: _TypeAlias = _typing.Literal["_animate_emoji", b"_animate_emoji"]  # noqa: Y015
        _WhichOneofReturnType__animate_stickers: _TypeAlias = _typing.Literal["animate_stickers"]  # noqa: Y015
        _WhichOneofArgType__animate_stickers: _TypeAlias = _typing.Literal["_animate_stickers", b"_animate_stickers"]  # noqa: Y015
        _WhichOneofReturnType__convert_emoticons: _TypeAlias = _typing.Literal["convert_emoticons"]  # noqa: Y015
        _WhichOneofArgType__convert_emoticons: _TypeAlias = _typing.Literal["_convert_emoticons", b"_convert_emoticons"]  # noqa: Y015
        _WhichOneofReturnType__default_reaction_emoji: _TypeAlias = _typing.Literal["default_reaction_emoji"]  # noqa: Y015
        _WhichOneofArgType__default_reaction_emoji: _TypeAlias = _typing.Literal["_default_reaction_emoji", b"_default_reaction_emoji"]  # noqa: Y015
        _WhichOneofReturnType__diversity_surrogate: _TypeAlias = _typing.Literal["diversity_surrogate"]  # noqa: Y015
        _WhichOneofArgType__diversity_surrogate: _TypeAlias = _typing.Literal["_diversity_surrogate", b"_diversity_surrogate"]  # noqa: Y015
        _WhichOneofReturnType__dm_spam_filter: _TypeAlias = _typing.Literal["dm_spam_filter"]  # noqa: Y015
        _WhichOneofArgType__dm_spam_filter: _TypeAlias = _typing.Literal["_dm_spam_filter", b"_dm_spam_filter"]  # noqa: Y015
        _WhichOneofReturnType__enable_tts_command: _TypeAlias = _typing.Literal["enable_tts_command"]  # noqa: Y015
        _WhichOneofArgType__enable_tts_command: _TypeAlias = _typing.Literal["_enable_tts_command", b"_enable_tts_command"]  # noqa: Y015
        _WhichOneofReturnType__explicit_content_filter: _TypeAlias = _typing.Literal["explicit_content_filter"]  # noqa: Y015
        _WhichOneofArgType__explicit_content_filter: _TypeAlias = _typing.Literal["_explicit_content_filter", b"_explicit_content_filter"]  # noqa: Y015
        _WhichOneofReturnType__explicit_content_settings: _TypeAlias = _typing.Literal["explicit_content_settings"]  # noqa: Y015
        _WhichOneofArgType__explicit_content_settings: _TypeAlias = _typing.Literal["_explicit_content_settings", b"_explicit_content_settings"]  # noqa: Y015
        _WhichOneofReturnType__expression_suggestions_enabled: _TypeAlias = _typing.Literal["expression_suggestions_enabled"]  # noqa: Y015
        _WhichOneofArgType__expression_suggestions_enabled: _TypeAlias = _typing.Literal["_expression_suggestions_enabled", b"_expression_suggestions_enabled"]  # noqa: Y015
        _WhichOneofReturnType__gif_auto_play: _TypeAlias = _typing.Literal["gif_auto_play"]  # noqa: Y015
        _WhichOneofArgType__gif_auto_play: _TypeAlias = _typing.Literal["_gif_auto_play", b"_gif_auto_play"]  # noqa: Y015
        _WhichOneofReturnType__gore_content_settings: _TypeAlias = _typing.Literal["gore_content_settings"]  # noqa: Y015
        _WhichOneofArgType__gore_content_settings: _TypeAlias = _typing.Literal["_gore_content_settings", b"_gore_content_settings"]  # noqa: Y015
        _WhichOneofReturnType__include_soundmoji_in_autocomplete: _TypeAlias = _typing.Literal["include_soundmoji_in_autocomplete"]  # noqa: Y015
        _WhichOneofArgType__include_soundmoji_in_autocomplete: _TypeAlias = _typing.Literal["_include_soundmoji_in_autocomplete", b"_include_soundmoji_in_autocomplete"]  # noqa: Y015
        _WhichOneofReturnType__include_stickers_in_autocomplete: _TypeAlias = _typing.Literal["include_stickers_in_autocomplete"]  # noqa: Y015
        _WhichOneofArgType__include_stickers_in_autocomplete: _TypeAlias = _typing.Literal["_include_stickers_in_autocomplete", b"_include_stickers_in_autocomplete"]  # noqa: Y015
        _WhichOneofReturnType__inline_attachment_media: _TypeAlias = _typing.Literal["inline_attachment_media"]  # noqa: Y015
        _WhichOneofArgType__inline_attachment_media: _TypeAlias = _typing.Literal["_inline_attachment_media", b"_inline_attachment_media"]  # noqa: Y015
        _WhichOneofReturnType__inline_embed_media: _TypeAlias = _typing.Literal["inline_embed_media"]  # noqa: Y015
        _WhichOneofArgType__inline_embed_media: _TypeAlias = _typing.Literal["_inline_embed_media", b"_inline_embed_media"]  # noqa: Y015
        _WhichOneofReturnType__is_cross_dm_search_enabled: _TypeAlias = _typing.Literal["is_cross_dm_search_enabled"]  # noqa: Y015
        _WhichOneofArgType__is_cross_dm_search_enabled: _TypeAlias = _typing.Literal["_is_cross_dm_search_enabled", b"_is_cross_dm_search_enabled"]  # noqa: Y015
        _WhichOneofReturnType__keyword_filter_settings: _TypeAlias = _typing.Literal["keyword_filter_settings"]  # noqa: Y015
        _WhichOneofArgType__keyword_filter_settings: _TypeAlias = _typing.Literal["_keyword_filter_settings", b"_keyword_filter_settings"]  # noqa: Y015
        _WhichOneofReturnType__message_display_compact: _TypeAlias = _typing.Literal["message_display_compact"]  # noqa: Y015
        _WhichOneofArgType__message_display_compact: _TypeAlias = _typing.Literal["_message_display_compact", b"_message_display_compact"]  # noqa: Y015
        _WhichOneofReturnType__render_embeds: _TypeAlias = _typing.Literal["render_embeds"]  # noqa: Y015
        _WhichOneofArgType__render_embeds: _TypeAlias = _typing.Literal["_render_embeds", b"_render_embeds"]  # noqa: Y015
        _WhichOneofReturnType__render_reactions: _TypeAlias = _typing.Literal["render_reactions"]  # noqa: Y015
        _WhichOneofArgType__render_reactions: _TypeAlias = _typing.Literal["_render_reactions", b"_render_reactions"]  # noqa: Y015
        _WhichOneofReturnType__render_spoilers: _TypeAlias = _typing.Literal["render_spoilers"]  # noqa: Y015
        _WhichOneofArgType__render_spoilers: _TypeAlias = _typing.Literal["_render_spoilers", b"_render_spoilers"]  # noqa: Y015
        _WhichOneofReturnType__self_harm_content_settings: _TypeAlias = _typing.Literal["self_harm_content_settings"]  # noqa: Y015
        _WhichOneofArgType__self_harm_content_settings: _TypeAlias = _typing.Literal["_self_harm_content_settings", b"_self_harm_content_settings"]  # noqa: Y015
        _WhichOneofReturnType__show_command_suggestions: _TypeAlias = _typing.Literal["show_command_suggestions"]  # noqa: Y015
        _WhichOneofArgType__show_command_suggestions: _TypeAlias = _typing.Literal["_show_command_suggestions", b"_show_command_suggestions"]  # noqa: Y015
        _WhichOneofReturnType__show_mention_suggestions: _TypeAlias = _typing.Literal["show_mention_suggestions"]  # noqa: Y015
        _WhichOneofArgType__show_mention_suggestions: _TypeAlias = _typing.Literal["_show_mention_suggestions", b"_show_mention_suggestions"]  # noqa: Y015
        _WhichOneofReturnType__use_legacy_chat_input: _TypeAlias = _typing.Literal["use_legacy_chat_input"]  # noqa: Y015
        _WhichOneofArgType__use_legacy_chat_input: _TypeAlias = _typing.Literal["_use_legacy_chat_input", b"_use_legacy_chat_input"]  # noqa: Y015
        _WhichOneofReturnType__use_rich_chat_input: _TypeAlias = _typing.Literal["use_rich_chat_input"]  # noqa: Y015
        _WhichOneofArgType__use_rich_chat_input: _TypeAlias = _typing.Literal["_use_rich_chat_input", b"_use_rich_chat_input"]  # noqa: Y015
        _WhichOneofReturnType__use_thread_sidebar: _TypeAlias = _typing.Literal["use_thread_sidebar"]  # noqa: Y015
        _WhichOneofArgType__use_thread_sidebar: _TypeAlias = _typing.Literal["_use_thread_sidebar", b"_use_thread_sidebar"]  # noqa: Y015
        _WhichOneofReturnType__view_image_descriptions: _TypeAlias = _typing.Literal["view_image_descriptions"]  # noqa: Y015
        _WhichOneofArgType__view_image_descriptions: _TypeAlias = _typing.Literal["_view_image_descriptions", b"_view_image_descriptions"]  # noqa: Y015
        _WhichOneofReturnType__view_nsfw_commands: _TypeAlias = _typing.Literal["view_nsfw_commands"]  # noqa: Y015
        _WhichOneofArgType__view_nsfw_commands: _TypeAlias = _typing.Literal["_view_nsfw_commands", b"_view_nsfw_commands"]  # noqa: Y015
        _WhichOneofReturnType__view_nsfw_guilds: _TypeAlias = _typing.Literal["view_nsfw_guilds"]  # noqa: Y015
        _WhichOneofArgType__view_nsfw_guilds: _TypeAlias = _typing.Literal["_view_nsfw_guilds", b"_view_nsfw_guilds"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__animate_emoji) -> _WhichOneofReturnType__animate_emoji | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__animate_stickers) -> _WhichOneofReturnType__animate_stickers | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__convert_emoticons) -> _WhichOneofReturnType__convert_emoticons | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__default_reaction_emoji) -> _WhichOneofReturnType__default_reaction_emoji | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__diversity_surrogate) -> _WhichOneofReturnType__diversity_surrogate | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__dm_spam_filter) -> _WhichOneofReturnType__dm_spam_filter | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_tts_command) -> _WhichOneofReturnType__enable_tts_command | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__explicit_content_filter) -> _WhichOneofReturnType__explicit_content_filter | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__explicit_content_settings) -> _WhichOneofReturnType__explicit_content_settings | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__expression_suggestions_enabled) -> _WhichOneofReturnType__expression_suggestions_enabled | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gif_auto_play) -> _WhichOneofReturnType__gif_auto_play | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gore_content_settings) -> _WhichOneofReturnType__gore_content_settings | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__include_soundmoji_in_autocomplete) -> _WhichOneofReturnType__include_soundmoji_in_autocomplete | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__include_stickers_in_autocomplete) -> _WhichOneofReturnType__include_stickers_in_autocomplete | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__inline_attachment_media) -> _WhichOneofReturnType__inline_attachment_media | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__inline_embed_media) -> _WhichOneofReturnType__inline_embed_media | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__is_cross_dm_search_enabled) -> _WhichOneofReturnType__is_cross_dm_search_enabled | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__keyword_filter_settings) -> _WhichOneofReturnType__keyword_filter_settings | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__message_display_compact) -> _WhichOneofReturnType__message_display_compact | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__render_embeds) -> _WhichOneofReturnType__render_embeds | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__render_reactions) -> _WhichOneofReturnType__render_reactions | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__render_spoilers) -> _WhichOneofReturnType__render_spoilers | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__self_harm_content_settings) -> _WhichOneofReturnType__self_harm_content_settings | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__show_command_suggestions) -> _WhichOneofReturnType__show_command_suggestions | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__show_mention_suggestions) -> _WhichOneofReturnType__show_mention_suggestions | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__use_legacy_chat_input) -> _WhichOneofReturnType__use_legacy_chat_input | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__use_rich_chat_input) -> _WhichOneofReturnType__use_rich_chat_input | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__use_thread_sidebar) -> _WhichOneofReturnType__use_thread_sidebar | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__view_image_descriptions) -> _WhichOneofReturnType__view_image_descriptions | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__view_nsfw_commands) -> _WhichOneofReturnType__view_nsfw_commands | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__view_nsfw_guilds) -> _WhichOneofReturnType__view_nsfw_guilds | None: ...

    @_typing.final
    class NotificationSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        SHOW_IN_APP_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        NOTIFY_FRIENDS_ON_GO_LIVE_FIELD_NUMBER: _builtins.int
        NOTIFICATION_CENTER_ACKED_BEFORE_ID_FIELD_NUMBER: _builtins.int
        ENABLE_BURST_REACTION_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        QUIET_MODE_FIELD_NUMBER: _builtins.int
        FOCUS_MODE_EXPIRES_AT_MS_FIELD_NUMBER: _builtins.int
        REACTION_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        GAME_ACTIVITY_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        CUSTOM_STATUS_PUSH_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        GAME_ACTIVITY_EXCLUDE_STEAM_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        ENABLE_VOICE_ACTIVITY_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        ENABLE_FRIEND_ONLINE_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        ENABLE_USER_RESURRECTION_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        ENABLE_FRIEND_ANNIVERSARY_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        ENABLE_GAME_UPDATE_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        ENABLE_PROFILE_UPDATES_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        ENABLE_SERVER_TRENDING_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        ENABLE_DM_REPLY_NUDGE_REMINDERS_FIELD_NUMBER: _builtins.int
        ENABLE_SUMMARY_REMINDER_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        ENABLE_GDM_ALL_REACTION_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        ENABLE_FRIEND_GAMING_ACTIVITY_NOTIFICATIONS_FIELD_NUMBER: _builtins.int
        notification_center_acked_before_id: _builtins.int
        focus_mode_expires_at_ms: _builtins.int
        reaction_notifications: Global___PreloadedUserSettings.ReactionNotificationType.ValueType
        game_activity_notifications: Global___PreloadedUserSettings.GameActivityNotificationType.ValueType
        custom_status_push_notifications: Global___PreloadedUserSettings.CustomStatusPushNotificationType.ValueType
        @_builtins.property
        def show_in_app_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def notify_friends_on_go_live(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_burst_reaction_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def quiet_mode(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def game_activity_exclude_steam_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_voice_activity_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_friend_online_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_user_resurrection_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_friend_anniversary_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_game_update_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_profile_updates_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_server_trending_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_dm_reply_nudge_reminders(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_summary_reminder_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_gdm_all_reaction_notifications(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def enable_friend_gaming_activity_notifications(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            show_in_app_notifications: _wrappers_pb2.BoolValue | None = ...,
            notify_friends_on_go_live: _wrappers_pb2.BoolValue | None = ...,
            notification_center_acked_before_id: _builtins.int = ...,
            enable_burst_reaction_notifications: _wrappers_pb2.BoolValue | None = ...,
            quiet_mode: _wrappers_pb2.BoolValue | None = ...,
            focus_mode_expires_at_ms: _builtins.int = ...,
            reaction_notifications: Global___PreloadedUserSettings.ReactionNotificationType.ValueType = ...,
            game_activity_notifications: Global___PreloadedUserSettings.GameActivityNotificationType.ValueType = ...,
            custom_status_push_notifications: Global___PreloadedUserSettings.CustomStatusPushNotificationType.ValueType = ...,
            game_activity_exclude_steam_notifications: _wrappers_pb2.BoolValue | None = ...,
            enable_voice_activity_notifications: _wrappers_pb2.BoolValue | None = ...,
            enable_friend_online_notifications: _wrappers_pb2.BoolValue | None = ...,
            enable_user_resurrection_notifications: _wrappers_pb2.BoolValue | None = ...,
            enable_friend_anniversary_notifications: _wrappers_pb2.BoolValue | None = ...,
            enable_game_update_notifications: _wrappers_pb2.BoolValue | None = ...,
            enable_profile_updates_notifications: _wrappers_pb2.BoolValue | None = ...,
            enable_server_trending_notifications: _wrappers_pb2.BoolValue | None = ...,
            enable_dm_reply_nudge_reminders: _wrappers_pb2.BoolValue | None = ...,
            enable_summary_reminder_notifications: _wrappers_pb2.BoolValue | None = ...,
            enable_gdm_all_reaction_notifications: _wrappers_pb2.BoolValue | None = ...,
            enable_friend_gaming_activity_notifications: _wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_enable_burst_reaction_notifications", b"_enable_burst_reaction_notifications", "_enable_dm_reply_nudge_reminders", b"_enable_dm_reply_nudge_reminders", "_enable_friend_anniversary_notifications", b"_enable_friend_anniversary_notifications", "_enable_friend_gaming_activity_notifications", b"_enable_friend_gaming_activity_notifications", "_enable_friend_online_notifications", b"_enable_friend_online_notifications", "_enable_game_update_notifications", b"_enable_game_update_notifications", "_enable_gdm_all_reaction_notifications", b"_enable_gdm_all_reaction_notifications", "_enable_profile_updates_notifications", b"_enable_profile_updates_notifications", "_enable_server_trending_notifications", b"_enable_server_trending_notifications", "_enable_summary_reminder_notifications", b"_enable_summary_reminder_notifications", "_enable_user_resurrection_notifications", b"_enable_user_resurrection_notifications", "_enable_voice_activity_notifications", b"_enable_voice_activity_notifications", "_game_activity_exclude_steam_notifications", b"_game_activity_exclude_steam_notifications", "_notify_friends_on_go_live", b"_notify_friends_on_go_live", "_quiet_mode", b"_quiet_mode", "_show_in_app_notifications", b"_show_in_app_notifications", "enable_burst_reaction_notifications", b"enable_burst_reaction_notifications", "enable_dm_reply_nudge_reminders", b"enable_dm_reply_nudge_reminders", "enable_friend_anniversary_notifications", b"enable_friend_anniversary_notifications", "enable_friend_gaming_activity_notifications", b"enable_friend_gaming_activity_notifications", "enable_friend_online_notifications", b"enable_friend_online_notifications", "enable_game_update_notifications", b"enable_game_update_notifications", "enable_gdm_all_reaction_notifications", b"enable_gdm_all_reaction_notifications", "enable_profile_updates_notifications", b"enable_profile_updates_notifications", "enable_server_trending_notifications", b"enable_server_trending_notifications", "enable_summary_reminder_notifications", b"enable_summary_reminder_notifications", "enable_user_resurrection_notifications", b"enable_user_resurrection_notifications", "enable_voice_activity_notifications", b"enable_voice_activity_notifications", "game_activity_exclude_steam_notifications", b"game_activity_exclude_steam_notifications", "notify_friends_on_go_live", b"notify_friends_on_go_live", "quiet_mode", b"quiet_mode", "show_in_app_notifications", b"show_in_app_notifications"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_enable_burst_reaction_notifications", b"_enable_burst_reaction_notifications", "_enable_dm_reply_nudge_reminders", b"_enable_dm_reply_nudge_reminders", "_enable_friend_anniversary_notifications", b"_enable_friend_anniversary_notifications", "_enable_friend_gaming_activity_notifications", b"_enable_friend_gaming_activity_notifications", "_enable_friend_online_notifications", b"_enable_friend_online_notifications", "_enable_game_update_notifications", b"_enable_game_update_notifications", "_enable_gdm_all_reaction_notifications", b"_enable_gdm_all_reaction_notifications", "_enable_profile_updates_notifications", b"_enable_profile_updates_notifications", "_enable_server_trending_notifications", b"_enable_server_trending_notifications", "_enable_summary_reminder_notifications", b"_enable_summary_reminder_notifications", "_enable_user_resurrection_notifications", b"_enable_user_resurrection_notifications", "_enable_voice_activity_notifications", b"_enable_voice_activity_notifications", "_game_activity_exclude_steam_notifications", b"_game_activity_exclude_steam_notifications", "_notify_friends_on_go_live", b"_notify_friends_on_go_live", "_quiet_mode", b"_quiet_mode", "_show_in_app_notifications", b"_show_in_app_notifications", "custom_status_push_notifications", b"custom_status_push_notifications", "enable_burst_reaction_notifications", b"enable_burst_reaction_notifications", "enable_dm_reply_nudge_reminders", b"enable_dm_reply_nudge_reminders", "enable_friend_anniversary_notifications", b"enable_friend_anniversary_notifications", "enable_friend_gaming_activity_notifications", b"enable_friend_gaming_activity_notifications", "enable_friend_online_notifications", b"enable_friend_online_notifications", "enable_game_update_notifications", b"enable_game_update_notifications", "enable_gdm_all_reaction_notifications", b"enable_gdm_all_reaction_notifications", "enable_profile_updates_notifications", b"enable_profile_updates_notifications", "enable_server_trending_notifications", b"enable_server_trending_notifications", "enable_summary_reminder_notifications", b"enable_summary_reminder_notifications", "enable_user_resurrection_notifications", b"enable_user_resurrection_notifications", "enable_voice_activity_notifications", b"enable_voice_activity_notifications", "focus_mode_expires_at_ms", b"focus_mode_expires_at_ms", "game_activity_exclude_steam_notifications", b"game_activity_exclude_steam_notifications", "game_activity_notifications", b"game_activity_notifications", "notification_center_acked_before_id", b"notification_center_acked_before_id", "notify_friends_on_go_live", b"notify_friends_on_go_live", "quiet_mode", b"quiet_mode", "reaction_notifications", b"reaction_notifications", "show_in_app_notifications", b"show_in_app_notifications"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__enable_burst_reaction_notifications: _TypeAlias = _typing.Literal["enable_burst_reaction_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_burst_reaction_notifications: _TypeAlias = _typing.Literal["_enable_burst_reaction_notifications", b"_enable_burst_reaction_notifications"]  # noqa: Y015
        _WhichOneofReturnType__enable_dm_reply_nudge_reminders: _TypeAlias = _typing.Literal["enable_dm_reply_nudge_reminders"]  # noqa: Y015
        _WhichOneofArgType__enable_dm_reply_nudge_reminders: _TypeAlias = _typing.Literal["_enable_dm_reply_nudge_reminders", b"_enable_dm_reply_nudge_reminders"]  # noqa: Y015
        _WhichOneofReturnType__enable_friend_anniversary_notifications: _TypeAlias = _typing.Literal["enable_friend_anniversary_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_friend_anniversary_notifications: _TypeAlias = _typing.Literal["_enable_friend_anniversary_notifications", b"_enable_friend_anniversary_notifications"]  # noqa: Y015
        _WhichOneofReturnType__enable_friend_gaming_activity_notifications: _TypeAlias = _typing.Literal["enable_friend_gaming_activity_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_friend_gaming_activity_notifications: _TypeAlias = _typing.Literal["_enable_friend_gaming_activity_notifications", b"_enable_friend_gaming_activity_notifications"]  # noqa: Y015
        _WhichOneofReturnType__enable_friend_online_notifications: _TypeAlias = _typing.Literal["enable_friend_online_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_friend_online_notifications: _TypeAlias = _typing.Literal["_enable_friend_online_notifications", b"_enable_friend_online_notifications"]  # noqa: Y015
        _WhichOneofReturnType__enable_game_update_notifications: _TypeAlias = _typing.Literal["enable_game_update_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_game_update_notifications: _TypeAlias = _typing.Literal["_enable_game_update_notifications", b"_enable_game_update_notifications"]  # noqa: Y015
        _WhichOneofReturnType__enable_gdm_all_reaction_notifications: _TypeAlias = _typing.Literal["enable_gdm_all_reaction_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_gdm_all_reaction_notifications: _TypeAlias = _typing.Literal["_enable_gdm_all_reaction_notifications", b"_enable_gdm_all_reaction_notifications"]  # noqa: Y015
        _WhichOneofReturnType__enable_profile_updates_notifications: _TypeAlias = _typing.Literal["enable_profile_updates_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_profile_updates_notifications: _TypeAlias = _typing.Literal["_enable_profile_updates_notifications", b"_enable_profile_updates_notifications"]  # noqa: Y015
        _WhichOneofReturnType__enable_server_trending_notifications: _TypeAlias = _typing.Literal["enable_server_trending_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_server_trending_notifications: _TypeAlias = _typing.Literal["_enable_server_trending_notifications", b"_enable_server_trending_notifications"]  # noqa: Y015
        _WhichOneofReturnType__enable_summary_reminder_notifications: _TypeAlias = _typing.Literal["enable_summary_reminder_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_summary_reminder_notifications: _TypeAlias = _typing.Literal["_enable_summary_reminder_notifications", b"_enable_summary_reminder_notifications"]  # noqa: Y015
        _WhichOneofReturnType__enable_user_resurrection_notifications: _TypeAlias = _typing.Literal["enable_user_resurrection_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_user_resurrection_notifications: _TypeAlias = _typing.Literal["_enable_user_resurrection_notifications", b"_enable_user_resurrection_notifications"]  # noqa: Y015
        _WhichOneofReturnType__enable_voice_activity_notifications: _TypeAlias = _typing.Literal["enable_voice_activity_notifications"]  # noqa: Y015
        _WhichOneofArgType__enable_voice_activity_notifications: _TypeAlias = _typing.Literal["_enable_voice_activity_notifications", b"_enable_voice_activity_notifications"]  # noqa: Y015
        _WhichOneofReturnType__game_activity_exclude_steam_notifications: _TypeAlias = _typing.Literal["game_activity_exclude_steam_notifications"]  # noqa: Y015
        _WhichOneofArgType__game_activity_exclude_steam_notifications: _TypeAlias = _typing.Literal["_game_activity_exclude_steam_notifications", b"_game_activity_exclude_steam_notifications"]  # noqa: Y015
        _WhichOneofReturnType__notify_friends_on_go_live: _TypeAlias = _typing.Literal["notify_friends_on_go_live"]  # noqa: Y015
        _WhichOneofArgType__notify_friends_on_go_live: _TypeAlias = _typing.Literal["_notify_friends_on_go_live", b"_notify_friends_on_go_live"]  # noqa: Y015
        _WhichOneofReturnType__quiet_mode: _TypeAlias = _typing.Literal["quiet_mode"]  # noqa: Y015
        _WhichOneofArgType__quiet_mode: _TypeAlias = _typing.Literal["_quiet_mode", b"_quiet_mode"]  # noqa: Y015
        _WhichOneofReturnType__show_in_app_notifications: _TypeAlias = _typing.Literal["show_in_app_notifications"]  # noqa: Y015
        _WhichOneofArgType__show_in_app_notifications: _TypeAlias = _typing.Literal["_show_in_app_notifications", b"_show_in_app_notifications"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_burst_reaction_notifications) -> _WhichOneofReturnType__enable_burst_reaction_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_dm_reply_nudge_reminders) -> _WhichOneofReturnType__enable_dm_reply_nudge_reminders | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_friend_anniversary_notifications) -> _WhichOneofReturnType__enable_friend_anniversary_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_friend_gaming_activity_notifications) -> _WhichOneofReturnType__enable_friend_gaming_activity_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_friend_online_notifications) -> _WhichOneofReturnType__enable_friend_online_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_game_update_notifications) -> _WhichOneofReturnType__enable_game_update_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_gdm_all_reaction_notifications) -> _WhichOneofReturnType__enable_gdm_all_reaction_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_profile_updates_notifications) -> _WhichOneofReturnType__enable_profile_updates_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_server_trending_notifications) -> _WhichOneofReturnType__enable_server_trending_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_summary_reminder_notifications) -> _WhichOneofReturnType__enable_summary_reminder_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_user_resurrection_notifications) -> _WhichOneofReturnType__enable_user_resurrection_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__enable_voice_activity_notifications) -> _WhichOneofReturnType__enable_voice_activity_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__game_activity_exclude_steam_notifications) -> _WhichOneofReturnType__game_activity_exclude_steam_notifications | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__notify_friends_on_go_live) -> _WhichOneofReturnType__notify_friends_on_go_live | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__quiet_mode) -> _WhichOneofReturnType__quiet_mode | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__show_in_app_notifications) -> _WhichOneofReturnType__show_in_app_notifications | None: ...

    @_typing.final
    class PrivacySettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ALLOW_ACTIVITY_PARTY_PRIVACY_FRIENDS_FIELD_NUMBER: _builtins.int
        ALLOW_ACTIVITY_PARTY_PRIVACY_VOICE_CHANNEL_FIELD_NUMBER: _builtins.int
        RESTRICTED_GUILD_IDS_FIELD_NUMBER: _builtins.int
        DEFAULT_GUILDS_RESTRICTED_FIELD_NUMBER: _builtins.int
        ALLOW_ACCESSIBILITY_DETECTION_FIELD_NUMBER: _builtins.int
        DETECT_PLATFORM_ACCOUNTS_FIELD_NUMBER: _builtins.int
        PASSWORDLESS_FIELD_NUMBER: _builtins.int
        CONTACT_SYNC_ENABLED_FIELD_NUMBER: _builtins.int
        FRIEND_SOURCE_FLAGS_FIELD_NUMBER: _builtins.int
        FRIEND_DISCOVERY_FLAGS_FIELD_NUMBER: _builtins.int
        ACTIVITY_RESTRICTED_GUILD_IDS_FIELD_NUMBER: _builtins.int
        DEFAULT_GUILDS_ACTIVITY_RESTRICTED_FIELD_NUMBER: _builtins.int
        ACTIVITY_JOINING_RESTRICTED_GUILD_IDS_FIELD_NUMBER: _builtins.int
        MESSAGE_REQUEST_RESTRICTED_GUILD_IDS_FIELD_NUMBER: _builtins.int
        DEFAULT_MESSAGE_REQUEST_RESTRICTED_FIELD_NUMBER: _builtins.int
        DROPS_OPTED_OUT_FIELD_NUMBER: _builtins.int
        NON_SPAM_RETRAINING_OPT_IN_FIELD_NUMBER: _builtins.int
        FAMILY_CENTER_ENABLED_FIELD_NUMBER: _builtins.int
        FAMILY_CENTER_ENABLED_V2_FIELD_NUMBER: _builtins.int
        HIDE_LEGACY_USERNAME_FIELD_NUMBER: _builtins.int
        INAPPROPRIATE_CONVERSATION_WARNINGS_FIELD_NUMBER: _builtins.int
        RECENT_GAMES_ENABLED_FIELD_NUMBER: _builtins.int
        GUILDS_LEADERBOARD_OPT_OUT_DEFAULT_FIELD_NUMBER: _builtins.int
        ALLOW_GAME_FRIEND_DMS_IN_DISCORD_FIELD_NUMBER: _builtins.int
        DEFAULT_GUILDS_RESTRICTED_V2_FIELD_NUMBER: _builtins.int
        SLAYER_SDK_RECEIVE_DMS_IN_GAME_FIELD_NUMBER: _builtins.int
        DEFAULT_GUILDS_ACTIVITY_RESTRICTED_V2_FIELD_NUMBER: _builtins.int
        QUESTS_3P_DATA_OPTED_OUT_FIELD_NUMBER: _builtins.int
        SHOW_LOCAL_TIME_FIELD_NUMBER: _builtins.int
        PROFILE_VISIBILITY_FIELD_NUMBER: _builtins.int
        default_guilds_restricted: _builtins.bool
        allow_accessibility_detection: _builtins.bool
        default_guilds_activity_restricted: Global___PreloadedUserSettings.GuildActivityStatusRestrictionDefault.ValueType
        guilds_leaderboard_opt_out_default: Global___PreloadedUserSettings.GuildsLeaderboardOptOutDefault.ValueType
        slayer_sdk_receive_dms_in_game: Global___PreloadedUserSettings.SlayerSDKReceiveInGameDMs.ValueType
        default_guilds_activity_restricted_v2: Global___PreloadedUserSettings.GuildActivityStatusRestrictionDefaultV2.ValueType
        profile_visibility: Global___PreloadedUserSettings.ProfileVisibility.ValueType
        @_builtins.property
        def allow_activity_party_privacy_friends(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def allow_activity_party_privacy_voice_channel(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def restricted_guild_ids(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        @_builtins.property
        def detect_platform_accounts(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def passwordless(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def contact_sync_enabled(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def friend_source_flags(self) -> _wrappers_pb2.UInt32Value: ...
        @_builtins.property
        def friend_discovery_flags(self) -> _wrappers_pb2.UInt32Value: ...
        @_builtins.property
        def activity_restricted_guild_ids(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        @_builtins.property
        def activity_joining_restricted_guild_ids(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        @_builtins.property
        def message_request_restricted_guild_ids(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        @_builtins.property
        def default_message_request_restricted(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def drops_opted_out(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def non_spam_retraining_opt_in(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def family_center_enabled(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def family_center_enabled_v2(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def hide_legacy_username(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def inappropriate_conversation_warnings(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def recent_games_enabled(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def allow_game_friend_dms_in_discord(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def default_guilds_restricted_v2(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def quests_3p_data_opted_out(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def show_local_time(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            allow_activity_party_privacy_friends: _wrappers_pb2.BoolValue | None = ...,
            allow_activity_party_privacy_voice_channel: _wrappers_pb2.BoolValue | None = ...,
            restricted_guild_ids: _abc.Iterable[_builtins.int] | None = ...,
            default_guilds_restricted: _builtins.bool = ...,
            allow_accessibility_detection: _builtins.bool = ...,
            detect_platform_accounts: _wrappers_pb2.BoolValue | None = ...,
            passwordless: _wrappers_pb2.BoolValue | None = ...,
            contact_sync_enabled: _wrappers_pb2.BoolValue | None = ...,
            friend_source_flags: _wrappers_pb2.UInt32Value | None = ...,
            friend_discovery_flags: _wrappers_pb2.UInt32Value | None = ...,
            activity_restricted_guild_ids: _abc.Iterable[_builtins.int] | None = ...,
            default_guilds_activity_restricted: Global___PreloadedUserSettings.GuildActivityStatusRestrictionDefault.ValueType = ...,
            activity_joining_restricted_guild_ids: _abc.Iterable[_builtins.int] | None = ...,
            message_request_restricted_guild_ids: _abc.Iterable[_builtins.int] | None = ...,
            default_message_request_restricted: _wrappers_pb2.BoolValue | None = ...,
            drops_opted_out: _wrappers_pb2.BoolValue | None = ...,
            non_spam_retraining_opt_in: _wrappers_pb2.BoolValue | None = ...,
            family_center_enabled: _wrappers_pb2.BoolValue | None = ...,
            family_center_enabled_v2: _wrappers_pb2.BoolValue | None = ...,
            hide_legacy_username: _wrappers_pb2.BoolValue | None = ...,
            inappropriate_conversation_warnings: _wrappers_pb2.BoolValue | None = ...,
            recent_games_enabled: _wrappers_pb2.BoolValue | None = ...,
            guilds_leaderboard_opt_out_default: Global___PreloadedUserSettings.GuildsLeaderboardOptOutDefault.ValueType = ...,
            allow_game_friend_dms_in_discord: _wrappers_pb2.BoolValue | None = ...,
            default_guilds_restricted_v2: _wrappers_pb2.BoolValue | None = ...,
            slayer_sdk_receive_dms_in_game: Global___PreloadedUserSettings.SlayerSDKReceiveInGameDMs.ValueType = ...,
            default_guilds_activity_restricted_v2: Global___PreloadedUserSettings.GuildActivityStatusRestrictionDefaultV2.ValueType = ...,
            quests_3p_data_opted_out: _wrappers_pb2.BoolValue | None = ...,
            show_local_time: _wrappers_pb2.BoolValue | None = ...,
            profile_visibility: Global___PreloadedUserSettings.ProfileVisibility.ValueType = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_allow_activity_party_privacy_friends", b"_allow_activity_party_privacy_friends", "_allow_activity_party_privacy_voice_channel", b"_allow_activity_party_privacy_voice_channel", "_allow_game_friend_dms_in_discord", b"_allow_game_friend_dms_in_discord", "_contact_sync_enabled", b"_contact_sync_enabled", "_default_guilds_restricted_v2", b"_default_guilds_restricted_v2", "_default_message_request_restricted", b"_default_message_request_restricted", "_detect_platform_accounts", b"_detect_platform_accounts", "_drops_opted_out", b"_drops_opted_out", "_family_center_enabled", b"_family_center_enabled", "_family_center_enabled_v2", b"_family_center_enabled_v2", "_friend_discovery_flags", b"_friend_discovery_flags", "_friend_source_flags", b"_friend_source_flags", "_hide_legacy_username", b"_hide_legacy_username", "_inappropriate_conversation_warnings", b"_inappropriate_conversation_warnings", "_non_spam_retraining_opt_in", b"_non_spam_retraining_opt_in", "_passwordless", b"_passwordless", "_quests_3p_data_opted_out", b"_quests_3p_data_opted_out", "_recent_games_enabled", b"_recent_games_enabled", "_show_local_time", b"_show_local_time", "allow_activity_party_privacy_friends", b"allow_activity_party_privacy_friends", "allow_activity_party_privacy_voice_channel", b"allow_activity_party_privacy_voice_channel", "allow_game_friend_dms_in_discord", b"allow_game_friend_dms_in_discord", "contact_sync_enabled", b"contact_sync_enabled", "default_guilds_restricted_v2", b"default_guilds_restricted_v2", "default_message_request_restricted", b"default_message_request_restricted", "detect_platform_accounts", b"detect_platform_accounts", "drops_opted_out", b"drops_opted_out", "family_center_enabled", b"family_center_enabled", "family_center_enabled_v2", b"family_center_enabled_v2", "friend_discovery_flags", b"friend_discovery_flags", "friend_source_flags", b"friend_source_flags", "hide_legacy_username", b"hide_legacy_username", "inappropriate_conversation_warnings", b"inappropriate_conversation_warnings", "non_spam_retraining_opt_in", b"non_spam_retraining_opt_in", "passwordless", b"passwordless", "quests_3p_data_opted_out", b"quests_3p_data_opted_out", "recent_games_enabled", b"recent_games_enabled", "show_local_time", b"show_local_time"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_allow_activity_party_privacy_friends", b"_allow_activity_party_privacy_friends", "_allow_activity_party_privacy_voice_channel", b"_allow_activity_party_privacy_voice_channel", "_allow_game_friend_dms_in_discord", b"_allow_game_friend_dms_in_discord", "_contact_sync_enabled", b"_contact_sync_enabled", "_default_guilds_restricted_v2", b"_default_guilds_restricted_v2", "_default_message_request_restricted", b"_default_message_request_restricted", "_detect_platform_accounts", b"_detect_platform_accounts", "_drops_opted_out", b"_drops_opted_out", "_family_center_enabled", b"_family_center_enabled", "_family_center_enabled_v2", b"_family_center_enabled_v2", "_friend_discovery_flags", b"_friend_discovery_flags", "_friend_source_flags", b"_friend_source_flags", "_hide_legacy_username", b"_hide_legacy_username", "_inappropriate_conversation_warnings", b"_inappropriate_conversation_warnings", "_non_spam_retraining_opt_in", b"_non_spam_retraining_opt_in", "_passwordless", b"_passwordless", "_quests_3p_data_opted_out", b"_quests_3p_data_opted_out", "_recent_games_enabled", b"_recent_games_enabled", "_show_local_time", b"_show_local_time", "activity_joining_restricted_guild_ids", b"activity_joining_restricted_guild_ids", "activity_restricted_guild_ids", b"activity_restricted_guild_ids", "allow_accessibility_detection", b"allow_accessibility_detection", "allow_activity_party_privacy_friends", b"allow_activity_party_privacy_friends", "allow_activity_party_privacy_voice_channel", b"allow_activity_party_privacy_voice_channel", "allow_game_friend_dms_in_discord", b"allow_game_friend_dms_in_discord", "contact_sync_enabled", b"contact_sync_enabled", "default_guilds_activity_restricted", b"default_guilds_activity_restricted", "default_guilds_activity_restricted_v2", b"default_guilds_activity_restricted_v2", "default_guilds_restricted", b"default_guilds_restricted", "default_guilds_restricted_v2", b"default_guilds_restricted_v2", "default_message_request_restricted", b"default_message_request_restricted", "detect_platform_accounts", b"detect_platform_accounts", "drops_opted_out", b"drops_opted_out", "family_center_enabled", b"family_center_enabled", "family_center_enabled_v2", b"family_center_enabled_v2", "friend_discovery_flags", b"friend_discovery_flags", "friend_source_flags", b"friend_source_flags", "guilds_leaderboard_opt_out_default", b"guilds_leaderboard_opt_out_default", "hide_legacy_username", b"hide_legacy_username", "inappropriate_conversation_warnings", b"inappropriate_conversation_warnings", "message_request_restricted_guild_ids", b"message_request_restricted_guild_ids", "non_spam_retraining_opt_in", b"non_spam_retraining_opt_in", "passwordless", b"passwordless", "profile_visibility", b"profile_visibility", "quests_3p_data_opted_out", b"quests_3p_data_opted_out", "recent_games_enabled", b"recent_games_enabled", "restricted_guild_ids", b"restricted_guild_ids", "show_local_time", b"show_local_time", "slayer_sdk_receive_dms_in_game", b"slayer_sdk_receive_dms_in_game"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__allow_activity_party_privacy_friends: _TypeAlias = _typing.Literal["allow_activity_party_privacy_friends"]  # noqa: Y015
        _WhichOneofArgType__allow_activity_party_privacy_friends: _TypeAlias = _typing.Literal["_allow_activity_party_privacy_friends", b"_allow_activity_party_privacy_friends"]  # noqa: Y015
        _WhichOneofReturnType__allow_activity_party_privacy_voice_channel: _TypeAlias = _typing.Literal["allow_activity_party_privacy_voice_channel"]  # noqa: Y015
        _WhichOneofArgType__allow_activity_party_privacy_voice_channel: _TypeAlias = _typing.Literal["_allow_activity_party_privacy_voice_channel", b"_allow_activity_party_privacy_voice_channel"]  # noqa: Y015
        _WhichOneofReturnType__allow_game_friend_dms_in_discord: _TypeAlias = _typing.Literal["allow_game_friend_dms_in_discord"]  # noqa: Y015
        _WhichOneofArgType__allow_game_friend_dms_in_discord: _TypeAlias = _typing.Literal["_allow_game_friend_dms_in_discord", b"_allow_game_friend_dms_in_discord"]  # noqa: Y015
        _WhichOneofReturnType__contact_sync_enabled: _TypeAlias = _typing.Literal["contact_sync_enabled"]  # noqa: Y015
        _WhichOneofArgType__contact_sync_enabled: _TypeAlias = _typing.Literal["_contact_sync_enabled", b"_contact_sync_enabled"]  # noqa: Y015
        _WhichOneofReturnType__default_guilds_restricted_v2: _TypeAlias = _typing.Literal["default_guilds_restricted_v2"]  # noqa: Y015
        _WhichOneofArgType__default_guilds_restricted_v2: _TypeAlias = _typing.Literal["_default_guilds_restricted_v2", b"_default_guilds_restricted_v2"]  # noqa: Y015
        _WhichOneofReturnType__default_message_request_restricted: _TypeAlias = _typing.Literal["default_message_request_restricted"]  # noqa: Y015
        _WhichOneofArgType__default_message_request_restricted: _TypeAlias = _typing.Literal["_default_message_request_restricted", b"_default_message_request_restricted"]  # noqa: Y015
        _WhichOneofReturnType__detect_platform_accounts: _TypeAlias = _typing.Literal["detect_platform_accounts"]  # noqa: Y015
        _WhichOneofArgType__detect_platform_accounts: _TypeAlias = _typing.Literal["_detect_platform_accounts", b"_detect_platform_accounts"]  # noqa: Y015
        _WhichOneofReturnType__drops_opted_out: _TypeAlias = _typing.Literal["drops_opted_out"]  # noqa: Y015
        _WhichOneofArgType__drops_opted_out: _TypeAlias = _typing.Literal["_drops_opted_out", b"_drops_opted_out"]  # noqa: Y015
        _WhichOneofReturnType__family_center_enabled: _TypeAlias = _typing.Literal["family_center_enabled"]  # noqa: Y015
        _WhichOneofArgType__family_center_enabled: _TypeAlias = _typing.Literal["_family_center_enabled", b"_family_center_enabled"]  # noqa: Y015
        _WhichOneofReturnType__family_center_enabled_v2: _TypeAlias = _typing.Literal["family_center_enabled_v2"]  # noqa: Y015
        _WhichOneofArgType__family_center_enabled_v2: _TypeAlias = _typing.Literal["_family_center_enabled_v2", b"_family_center_enabled_v2"]  # noqa: Y015
        _WhichOneofReturnType__friend_discovery_flags: _TypeAlias = _typing.Literal["friend_discovery_flags"]  # noqa: Y015
        _WhichOneofArgType__friend_discovery_flags: _TypeAlias = _typing.Literal["_friend_discovery_flags", b"_friend_discovery_flags"]  # noqa: Y015
        _WhichOneofReturnType__friend_source_flags: _TypeAlias = _typing.Literal["friend_source_flags"]  # noqa: Y015
        _WhichOneofArgType__friend_source_flags: _TypeAlias = _typing.Literal["_friend_source_flags", b"_friend_source_flags"]  # noqa: Y015
        _WhichOneofReturnType__hide_legacy_username: _TypeAlias = _typing.Literal["hide_legacy_username"]  # noqa: Y015
        _WhichOneofArgType__hide_legacy_username: _TypeAlias = _typing.Literal["_hide_legacy_username", b"_hide_legacy_username"]  # noqa: Y015
        _WhichOneofReturnType__inappropriate_conversation_warnings: _TypeAlias = _typing.Literal["inappropriate_conversation_warnings"]  # noqa: Y015
        _WhichOneofArgType__inappropriate_conversation_warnings: _TypeAlias = _typing.Literal["_inappropriate_conversation_warnings", b"_inappropriate_conversation_warnings"]  # noqa: Y015
        _WhichOneofReturnType__non_spam_retraining_opt_in: _TypeAlias = _typing.Literal["non_spam_retraining_opt_in"]  # noqa: Y015
        _WhichOneofArgType__non_spam_retraining_opt_in: _TypeAlias = _typing.Literal["_non_spam_retraining_opt_in", b"_non_spam_retraining_opt_in"]  # noqa: Y015
        _WhichOneofReturnType__passwordless: _TypeAlias = _typing.Literal["passwordless"]  # noqa: Y015
        _WhichOneofArgType__passwordless: _TypeAlias = _typing.Literal["_passwordless", b"_passwordless"]  # noqa: Y015
        _WhichOneofReturnType__quests_3p_data_opted_out: _TypeAlias = _typing.Literal["quests_3p_data_opted_out"]  # noqa: Y015
        _WhichOneofArgType__quests_3p_data_opted_out: _TypeAlias = _typing.Literal["_quests_3p_data_opted_out", b"_quests_3p_data_opted_out"]  # noqa: Y015
        _WhichOneofReturnType__recent_games_enabled: _TypeAlias = _typing.Literal["recent_games_enabled"]  # noqa: Y015
        _WhichOneofArgType__recent_games_enabled: _TypeAlias = _typing.Literal["_recent_games_enabled", b"_recent_games_enabled"]  # noqa: Y015
        _WhichOneofReturnType__show_local_time: _TypeAlias = _typing.Literal["show_local_time"]  # noqa: Y015
        _WhichOneofArgType__show_local_time: _TypeAlias = _typing.Literal["_show_local_time", b"_show_local_time"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__allow_activity_party_privacy_friends) -> _WhichOneofReturnType__allow_activity_party_privacy_friends | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__allow_activity_party_privacy_voice_channel) -> _WhichOneofReturnType__allow_activity_party_privacy_voice_channel | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__allow_game_friend_dms_in_discord) -> _WhichOneofReturnType__allow_game_friend_dms_in_discord | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__contact_sync_enabled) -> _WhichOneofReturnType__contact_sync_enabled | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__default_guilds_restricted_v2) -> _WhichOneofReturnType__default_guilds_restricted_v2 | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__default_message_request_restricted) -> _WhichOneofReturnType__default_message_request_restricted | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__detect_platform_accounts) -> _WhichOneofReturnType__detect_platform_accounts | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__drops_opted_out) -> _WhichOneofReturnType__drops_opted_out | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__family_center_enabled) -> _WhichOneofReturnType__family_center_enabled | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__family_center_enabled_v2) -> _WhichOneofReturnType__family_center_enabled_v2 | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__friend_discovery_flags) -> _WhichOneofReturnType__friend_discovery_flags | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__friend_source_flags) -> _WhichOneofReturnType__friend_source_flags | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__hide_legacy_username) -> _WhichOneofReturnType__hide_legacy_username | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__inappropriate_conversation_warnings) -> _WhichOneofReturnType__inappropriate_conversation_warnings | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__non_spam_retraining_opt_in) -> _WhichOneofReturnType__non_spam_retraining_opt_in | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__passwordless) -> _WhichOneofReturnType__passwordless | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__quests_3p_data_opted_out) -> _WhichOneofReturnType__quests_3p_data_opted_out | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__recent_games_enabled) -> _WhichOneofReturnType__recent_games_enabled | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__show_local_time) -> _WhichOneofReturnType__show_local_time | None: ...

    @_typing.final
    class DebugSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        RTC_PANEL_SHOW_VOICE_STATES_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def rtc_panel_show_voice_states(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            rtc_panel_show_voice_states: _wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_rtc_panel_show_voice_states", b"_rtc_panel_show_voice_states", "rtc_panel_show_voice_states", b"rtc_panel_show_voice_states"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_rtc_panel_show_voice_states", b"_rtc_panel_show_voice_states", "rtc_panel_show_voice_states", b"rtc_panel_show_voice_states"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__rtc_panel_show_voice_states: _TypeAlias = _typing.Literal["rtc_panel_show_voice_states"]  # noqa: Y015
        _WhichOneofArgType__rtc_panel_show_voice_states: _TypeAlias = _typing.Literal["_rtc_panel_show_voice_states", b"_rtc_panel_show_voice_states"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__rtc_panel_show_voice_states) -> _WhichOneofReturnType__rtc_panel_show_voice_states | None: ...

    @_typing.final
    class GameLibrarySettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        INSTALL_SHORTCUT_DESKTOP_FIELD_NUMBER: _builtins.int
        INSTALL_SHORTCUT_START_MENU_FIELD_NUMBER: _builtins.int
        DISABLE_GAMES_TAB_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def install_shortcut_desktop(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def install_shortcut_start_menu(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def disable_games_tab(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            install_shortcut_desktop: _wrappers_pb2.BoolValue | None = ...,
            install_shortcut_start_menu: _wrappers_pb2.BoolValue | None = ...,
            disable_games_tab: _wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_disable_games_tab", b"_disable_games_tab", "_install_shortcut_desktop", b"_install_shortcut_desktop", "_install_shortcut_start_menu", b"_install_shortcut_start_menu", "disable_games_tab", b"disable_games_tab", "install_shortcut_desktop", b"install_shortcut_desktop", "install_shortcut_start_menu", b"install_shortcut_start_menu"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_disable_games_tab", b"_disable_games_tab", "_install_shortcut_desktop", b"_install_shortcut_desktop", "_install_shortcut_start_menu", b"_install_shortcut_start_menu", "disable_games_tab", b"disable_games_tab", "install_shortcut_desktop", b"install_shortcut_desktop", "install_shortcut_start_menu", b"install_shortcut_start_menu"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__disable_games_tab: _TypeAlias = _typing.Literal["disable_games_tab"]  # noqa: Y015
        _WhichOneofArgType__disable_games_tab: _TypeAlias = _typing.Literal["_disable_games_tab", b"_disable_games_tab"]  # noqa: Y015
        _WhichOneofReturnType__install_shortcut_desktop: _TypeAlias = _typing.Literal["install_shortcut_desktop"]  # noqa: Y015
        _WhichOneofArgType__install_shortcut_desktop: _TypeAlias = _typing.Literal["_install_shortcut_desktop", b"_install_shortcut_desktop"]  # noqa: Y015
        _WhichOneofReturnType__install_shortcut_start_menu: _TypeAlias = _typing.Literal["install_shortcut_start_menu"]  # noqa: Y015
        _WhichOneofArgType__install_shortcut_start_menu: _TypeAlias = _typing.Literal["_install_shortcut_start_menu", b"_install_shortcut_start_menu"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__disable_games_tab) -> _WhichOneofReturnType__disable_games_tab | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__install_shortcut_desktop) -> _WhichOneofReturnType__install_shortcut_desktop | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__install_shortcut_start_menu) -> _WhichOneofReturnType__install_shortcut_start_menu | None: ...

    @_typing.final
    class CustomStatus(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        TEXT_FIELD_NUMBER: _builtins.int
        EMOJI_ID_FIELD_NUMBER: _builtins.int
        EMOJI_NAME_FIELD_NUMBER: _builtins.int
        EXPIRES_AT_MS_FIELD_NUMBER: _builtins.int
        CREATED_AT_MS_FIELD_NUMBER: _builtins.int
        LABEL_FIELD_NUMBER: _builtins.int
        text: _builtins.str
        emoji_id: _builtins.int
        emoji_name: _builtins.str
        expires_at_ms: _builtins.int
        created_at_ms: _builtins.int
        @_builtins.property
        def label(self) -> _wrappers_pb2.StringValue: ...
        def __init__(
            self,
            *,
            text: _builtins.str = ...,
            emoji_id: _builtins.int = ...,
            emoji_name: _builtins.str = ...,
            expires_at_ms: _builtins.int = ...,
            created_at_ms: _builtins.int = ...,
            label: _wrappers_pb2.StringValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_label", b"_label", "label", b"label"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_label", b"_label", "created_at_ms", b"created_at_ms", "emoji_id", b"emoji_id", "emoji_name", b"emoji_name", "expires_at_ms", b"expires_at_ms", "label", b"label", "text", b"text"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__label: _TypeAlias = _typing.Literal["label"]  # noqa: Y015
        _WhichOneofArgType__label: _TypeAlias = _typing.Literal["_label", b"_label"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__label) -> _WhichOneofReturnType__label | None: ...

    @_typing.final
    class StatusSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        STATUS_FIELD_NUMBER: _builtins.int
        CUSTOM_STATUS_FIELD_NUMBER: _builtins.int
        SHOW_CURRENT_GAME_FIELD_NUMBER: _builtins.int
        STATUS_EXPIRES_AT_MS_FIELD_NUMBER: _builtins.int
        STATUS_CREATED_AT_MS_FIELD_NUMBER: _builtins.int
        status_expires_at_ms: _builtins.int
        @_builtins.property
        def status(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def custom_status(self) -> Global___PreloadedUserSettings.CustomStatus: ...
        @_builtins.property
        def show_current_game(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def status_created_at_ms(self) -> _wrappers_pb2.UInt64Value: ...
        def __init__(
            self,
            *,
            status: _wrappers_pb2.StringValue | None = ...,
            custom_status: Global___PreloadedUserSettings.CustomStatus | None = ...,
            show_current_game: _wrappers_pb2.BoolValue | None = ...,
            status_expires_at_ms: _builtins.int = ...,
            status_created_at_ms: _wrappers_pb2.UInt64Value | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_custom_status", b"_custom_status", "_show_current_game", b"_show_current_game", "_status", b"_status", "_status_created_at_ms", b"_status_created_at_ms", "custom_status", b"custom_status", "show_current_game", b"show_current_game", "status", b"status", "status_created_at_ms", b"status_created_at_ms"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_custom_status", b"_custom_status", "_show_current_game", b"_show_current_game", "_status", b"_status", "_status_created_at_ms", b"_status_created_at_ms", "custom_status", b"custom_status", "show_current_game", b"show_current_game", "status", b"status", "status_created_at_ms", b"status_created_at_ms", "status_expires_at_ms", b"status_expires_at_ms"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__custom_status: _TypeAlias = _typing.Literal["custom_status"]  # noqa: Y015
        _WhichOneofArgType__custom_status: _TypeAlias = _typing.Literal["_custom_status", b"_custom_status"]  # noqa: Y015
        _WhichOneofReturnType__show_current_game: _TypeAlias = _typing.Literal["show_current_game"]  # noqa: Y015
        _WhichOneofArgType__show_current_game: _TypeAlias = _typing.Literal["_show_current_game", b"_show_current_game"]  # noqa: Y015
        _WhichOneofReturnType__status: _TypeAlias = _typing.Literal["status"]  # noqa: Y015
        _WhichOneofArgType__status: _TypeAlias = _typing.Literal["_status", b"_status"]  # noqa: Y015
        _WhichOneofReturnType__status_created_at_ms: _TypeAlias = _typing.Literal["status_created_at_ms"]  # noqa: Y015
        _WhichOneofArgType__status_created_at_ms: _TypeAlias = _typing.Literal["_status_created_at_ms", b"_status_created_at_ms"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__custom_status) -> _WhichOneofReturnType__custom_status | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__show_current_game) -> _WhichOneofReturnType__show_current_game | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__status) -> _WhichOneofReturnType__status | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__status_created_at_ms) -> _WhichOneofReturnType__status_created_at_ms | None: ...

    @_typing.final
    class LocalizationSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LOCALE_FIELD_NUMBER: _builtins.int
        TIMEZONE_OFFSET_FIELD_NUMBER: _builtins.int
        TIMEZONE_NAME_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def locale(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def timezone_offset(self) -> _wrappers_pb2.Int32Value: ...
        @_builtins.property
        def timezone_name(self) -> _wrappers_pb2.StringValue: ...
        def __init__(
            self,
            *,
            locale: _wrappers_pb2.StringValue | None = ...,
            timezone_offset: _wrappers_pb2.Int32Value | None = ...,
            timezone_name: _wrappers_pb2.StringValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_locale", b"_locale", "_timezone_name", b"_timezone_name", "_timezone_offset", b"_timezone_offset", "locale", b"locale", "timezone_name", b"timezone_name", "timezone_offset", b"timezone_offset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_locale", b"_locale", "_timezone_name", b"_timezone_name", "_timezone_offset", b"_timezone_offset", "locale", b"locale", "timezone_name", b"timezone_name", "timezone_offset", b"timezone_offset"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__locale: _TypeAlias = _typing.Literal["locale"]  # noqa: Y015
        _WhichOneofArgType__locale: _TypeAlias = _typing.Literal["_locale", b"_locale"]  # noqa: Y015
        _WhichOneofReturnType__timezone_name: _TypeAlias = _typing.Literal["timezone_name"]  # noqa: Y015
        _WhichOneofArgType__timezone_name: _TypeAlias = _typing.Literal["_timezone_name", b"_timezone_name"]  # noqa: Y015
        _WhichOneofReturnType__timezone_offset: _TypeAlias = _typing.Literal["timezone_offset"]  # noqa: Y015
        _WhichOneofArgType__timezone_offset: _TypeAlias = _typing.Literal["_timezone_offset", b"_timezone_offset"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__locale) -> _WhichOneofReturnType__locale | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__timezone_name) -> _WhichOneofReturnType__timezone_name | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__timezone_offset) -> _WhichOneofReturnType__timezone_offset | None: ...

    @_typing.final
    class CustomUserThemeSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COLORS_FIELD_NUMBER: _builtins.int
        GRADIENT_COLOR_STOPS_FIELD_NUMBER: _builtins.int
        GRADIENT_ANGLE_FIELD_NUMBER: _builtins.int
        BASE_MIX_FIELD_NUMBER: _builtins.int
        gradient_angle: _builtins.int
        base_mix: _builtins.int
        @_builtins.property
        def colors(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
        @_builtins.property
        def gradient_color_stops(self) -> _containers.RepeatedScalarFieldContainer[_builtins.float]: ...
        def __init__(
            self,
            *,
            colors: _abc.Iterable[_builtins.str] | None = ...,
            gradient_color_stops: _abc.Iterable[_builtins.float] | None = ...,
            gradient_angle: _builtins.int = ...,
            base_mix: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["base_mix", b"base_mix", "colors", b"colors", "gradient_angle", b"gradient_angle", "gradient_color_stops", b"gradient_color_stops"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class ClientThemeSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BACKGROUND_GRADIENT_PRESET_ID_FIELD_NUMBER: _builtins.int
        CUSTOM_USER_THEME_SETTINGS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def background_gradient_preset_id(self) -> _wrappers_pb2.UInt32Value: ...
        @_builtins.property
        def custom_user_theme_settings(self) -> Global___PreloadedUserSettings.CustomUserThemeSettings: ...
        def __init__(
            self,
            *,
            background_gradient_preset_id: _wrappers_pb2.UInt32Value | None = ...,
            custom_user_theme_settings: Global___PreloadedUserSettings.CustomUserThemeSettings | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_background_gradient_preset_id", b"_background_gradient_preset_id", "_custom_user_theme_settings", b"_custom_user_theme_settings", "background_gradient_preset_id", b"background_gradient_preset_id", "custom_user_theme_settings", b"custom_user_theme_settings"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_background_gradient_preset_id", b"_background_gradient_preset_id", "_custom_user_theme_settings", b"_custom_user_theme_settings", "background_gradient_preset_id", b"background_gradient_preset_id", "custom_user_theme_settings", b"custom_user_theme_settings"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__background_gradient_preset_id: _TypeAlias = _typing.Literal["background_gradient_preset_id"]  # noqa: Y015
        _WhichOneofArgType__background_gradient_preset_id: _TypeAlias = _typing.Literal["_background_gradient_preset_id", b"_background_gradient_preset_id"]  # noqa: Y015
        _WhichOneofReturnType__custom_user_theme_settings: _TypeAlias = _typing.Literal["custom_user_theme_settings"]  # noqa: Y015
        _WhichOneofArgType__custom_user_theme_settings: _TypeAlias = _typing.Literal["_custom_user_theme_settings", b"_custom_user_theme_settings"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__background_gradient_preset_id) -> _WhichOneofReturnType__background_gradient_preset_id | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__custom_user_theme_settings) -> _WhichOneofReturnType__custom_user_theme_settings | None: ...

    @_typing.final
    class AppearanceSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        THEME_FIELD_NUMBER: _builtins.int
        DEVELOPER_MODE_FIELD_NUMBER: _builtins.int
        CLIENT_THEME_SETTINGS_FIELD_NUMBER: _builtins.int
        MOBILE_REDESIGN_DISABLED_FIELD_NUMBER: _builtins.int
        CHANNEL_LIST_LAYOUT_FIELD_NUMBER: _builtins.int
        MESSAGE_PREVIEWS_FIELD_NUMBER: _builtins.int
        SEARCH_RESULT_EXACT_COUNT_ENABLED_FIELD_NUMBER: _builtins.int
        TIMESTAMP_HOUR_CYCLE_FIELD_NUMBER: _builtins.int
        HAPPENING_NOW_CARDS_DISABLED_FIELD_NUMBER: _builtins.int
        LAUNCH_PAD_MODE_FIELD_NUMBER: _builtins.int
        UI_DENSITY_FIELD_NUMBER: _builtins.int
        SWIPE_RIGHT_TO_LEFT_MODE_FIELD_NUMBER: _builtins.int
        theme: Global___PreloadedUserSettings.Theme.ValueType
        developer_mode: _builtins.bool
        mobile_redesign_disabled: _builtins.bool
        timestamp_hour_cycle: Global___PreloadedUserSettings.TimestampHourCycle.ValueType
        launch_pad_mode: Global___PreloadedUserSettings.LaunchPadMode.ValueType
        ui_density: Global___PreloadedUserSettings.UIDensity.ValueType
        swipe_right_to_left_mode: Global___PreloadedUserSettings.SwipeRightToLeftMode.ValueType
        @_builtins.property
        def client_theme_settings(self) -> Global___PreloadedUserSettings.ClientThemeSettings: ...
        @_builtins.property
        def channel_list_layout(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def message_previews(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def search_result_exact_count_enabled(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def happening_now_cards_disabled(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            theme: Global___PreloadedUserSettings.Theme.ValueType = ...,
            developer_mode: _builtins.bool = ...,
            client_theme_settings: Global___PreloadedUserSettings.ClientThemeSettings | None = ...,
            mobile_redesign_disabled: _builtins.bool = ...,
            channel_list_layout: _wrappers_pb2.StringValue | None = ...,
            message_previews: _wrappers_pb2.StringValue | None = ...,
            search_result_exact_count_enabled: _wrappers_pb2.BoolValue | None = ...,
            timestamp_hour_cycle: Global___PreloadedUserSettings.TimestampHourCycle.ValueType = ...,
            happening_now_cards_disabled: _wrappers_pb2.BoolValue | None = ...,
            launch_pad_mode: Global___PreloadedUserSettings.LaunchPadMode.ValueType = ...,
            ui_density: Global___PreloadedUserSettings.UIDensity.ValueType = ...,
            swipe_right_to_left_mode: Global___PreloadedUserSettings.SwipeRightToLeftMode.ValueType = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_channel_list_layout", b"_channel_list_layout", "_client_theme_settings", b"_client_theme_settings", "_happening_now_cards_disabled", b"_happening_now_cards_disabled", "_message_previews", b"_message_previews", "_search_result_exact_count_enabled", b"_search_result_exact_count_enabled", "channel_list_layout", b"channel_list_layout", "client_theme_settings", b"client_theme_settings", "happening_now_cards_disabled", b"happening_now_cards_disabled", "message_previews", b"message_previews", "search_result_exact_count_enabled", b"search_result_exact_count_enabled"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_channel_list_layout", b"_channel_list_layout", "_client_theme_settings", b"_client_theme_settings", "_happening_now_cards_disabled", b"_happening_now_cards_disabled", "_message_previews", b"_message_previews", "_search_result_exact_count_enabled", b"_search_result_exact_count_enabled", "channel_list_layout", b"channel_list_layout", "client_theme_settings", b"client_theme_settings", "developer_mode", b"developer_mode", "happening_now_cards_disabled", b"happening_now_cards_disabled", "launch_pad_mode", b"launch_pad_mode", "message_previews", b"message_previews", "mobile_redesign_disabled", b"mobile_redesign_disabled", "search_result_exact_count_enabled", b"search_result_exact_count_enabled", "swipe_right_to_left_mode", b"swipe_right_to_left_mode", "theme", b"theme", "timestamp_hour_cycle", b"timestamp_hour_cycle", "ui_density", b"ui_density"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__channel_list_layout: _TypeAlias = _typing.Literal["channel_list_layout"]  # noqa: Y015
        _WhichOneofArgType__channel_list_layout: _TypeAlias = _typing.Literal["_channel_list_layout", b"_channel_list_layout"]  # noqa: Y015
        _WhichOneofReturnType__client_theme_settings: _TypeAlias = _typing.Literal["client_theme_settings"]  # noqa: Y015
        _WhichOneofArgType__client_theme_settings: _TypeAlias = _typing.Literal["_client_theme_settings", b"_client_theme_settings"]  # noqa: Y015
        _WhichOneofReturnType__happening_now_cards_disabled: _TypeAlias = _typing.Literal["happening_now_cards_disabled"]  # noqa: Y015
        _WhichOneofArgType__happening_now_cards_disabled: _TypeAlias = _typing.Literal["_happening_now_cards_disabled", b"_happening_now_cards_disabled"]  # noqa: Y015
        _WhichOneofReturnType__message_previews: _TypeAlias = _typing.Literal["message_previews"]  # noqa: Y015
        _WhichOneofArgType__message_previews: _TypeAlias = _typing.Literal["_message_previews", b"_message_previews"]  # noqa: Y015
        _WhichOneofReturnType__search_result_exact_count_enabled: _TypeAlias = _typing.Literal["search_result_exact_count_enabled"]  # noqa: Y015
        _WhichOneofArgType__search_result_exact_count_enabled: _TypeAlias = _typing.Literal["_search_result_exact_count_enabled", b"_search_result_exact_count_enabled"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__channel_list_layout) -> _WhichOneofReturnType__channel_list_layout | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__client_theme_settings) -> _WhichOneofReturnType__client_theme_settings | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__happening_now_cards_disabled) -> _WhichOneofReturnType__happening_now_cards_disabled | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__message_previews) -> _WhichOneofReturnType__message_previews | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__search_result_exact_count_enabled) -> _WhichOneofReturnType__search_result_exact_count_enabled | None: ...

    @_typing.final
    class GuildFolder(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        GUILD_IDS_FIELD_NUMBER: _builtins.int
        ID_FIELD_NUMBER: _builtins.int
        NAME_FIELD_NUMBER: _builtins.int
        COLOR_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def guild_ids(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        @_builtins.property
        def id(self) -> _wrappers_pb2.Int64Value: ...
        @_builtins.property
        def name(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def color(self) -> _wrappers_pb2.UInt64Value: ...
        def __init__(
            self,
            *,
            guild_ids: _abc.Iterable[_builtins.int] | None = ...,
            id: _wrappers_pb2.Int64Value | None = ...,
            name: _wrappers_pb2.StringValue | None = ...,
            color: _wrappers_pb2.UInt64Value | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_color", b"_color", "_id", b"_id", "_name", b"_name", "color", b"color", "id", b"id", "name", b"name"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_color", b"_color", "_id", b"_id", "_name", b"_name", "color", b"color", "guild_ids", b"guild_ids", "id", b"id", "name", b"name"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__color: _TypeAlias = _typing.Literal["color"]  # noqa: Y015
        _WhichOneofArgType__color: _TypeAlias = _typing.Literal["_color", b"_color"]  # noqa: Y015
        _WhichOneofReturnType__id: _TypeAlias = _typing.Literal["id"]  # noqa: Y015
        _WhichOneofArgType__id: _TypeAlias = _typing.Literal["_id", b"_id"]  # noqa: Y015
        _WhichOneofReturnType__name: _TypeAlias = _typing.Literal["name"]  # noqa: Y015
        _WhichOneofArgType__name: _TypeAlias = _typing.Literal["_name", b"_name"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__color) -> _WhichOneofReturnType__color | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__id) -> _WhichOneofReturnType__id | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__name) -> _WhichOneofReturnType__name | None: ...

    @_typing.final
    class GuildFolders(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        FOLDERS_FIELD_NUMBER: _builtins.int
        GUILD_POSITIONS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def folders(self) -> _containers.RepeatedCompositeFieldContainer[Global___PreloadedUserSettings.GuildFolder]: ...
        @_builtins.property
        def guild_positions(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        def __init__(
            self,
            *,
            folders: _abc.Iterable[Global___PreloadedUserSettings.GuildFolder] | None = ...,
            guild_positions: _abc.Iterable[_builtins.int] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["folders", b"folders", "guild_positions", b"guild_positions"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class FavoriteChannel(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        NICKNAME_FIELD_NUMBER: _builtins.int
        TYPE_FIELD_NUMBER: _builtins.int
        POSITION_FIELD_NUMBER: _builtins.int
        PARENT_ID_FIELD_NUMBER: _builtins.int
        nickname: _builtins.str
        type: Global___PreloadedUserSettings.FavoriteChannelType.ValueType
        position: _builtins.int
        parent_id: _builtins.int
        def __init__(
            self,
            *,
            nickname: _builtins.str = ...,
            type: Global___PreloadedUserSettings.FavoriteChannelType.ValueType = ...,
            position: _builtins.int = ...,
            parent_id: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["nickname", b"nickname", "parent_id", b"parent_id", "position", b"position", "type", b"type"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class Favorites(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class FavoriteChannelsEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___PreloadedUserSettings.FavoriteChannel: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___PreloadedUserSettings.FavoriteChannel | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        FAVORITE_CHANNELS_FIELD_NUMBER: _builtins.int
        MUTED_FIELD_NUMBER: _builtins.int
        GUILD_VISIBLE_FIELD_NUMBER: _builtins.int
        muted: _builtins.bool
        @_builtins.property
        def favorite_channels(self) -> _containers.MessageMap[_builtins.int, Global___PreloadedUserSettings.FavoriteChannel]: ...
        @_builtins.property
        def guild_visible(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            favorite_channels: _abc.Mapping[_builtins.int, Global___PreloadedUserSettings.FavoriteChannel] | None = ...,
            muted: _builtins.bool = ...,
            guild_visible: _wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_guild_visible", b"_guild_visible", "guild_visible", b"guild_visible"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_guild_visible", b"_guild_visible", "favorite_channels", b"favorite_channels", "guild_visible", b"guild_visible", "muted", b"muted"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__guild_visible: _TypeAlias = _typing.Literal["guild_visible"]  # noqa: Y015
        _WhichOneofArgType__guild_visible: _TypeAlias = _typing.Literal["_guild_visible", b"_guild_visible"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__guild_visible) -> _WhichOneofReturnType__guild_visible | None: ...

    @_typing.final
    class AudioContextSetting(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        MUTED_FIELD_NUMBER: _builtins.int
        VOLUME_FIELD_NUMBER: _builtins.int
        MODIFIED_AT_FIELD_NUMBER: _builtins.int
        SOUNDBOARD_MUTED_FIELD_NUMBER: _builtins.int
        muted: _builtins.bool
        volume: _builtins.float
        modified_at: _builtins.int
        soundboard_muted: _builtins.bool
        def __init__(
            self,
            *,
            muted: _builtins.bool = ...,
            volume: _builtins.float = ...,
            modified_at: _builtins.int = ...,
            soundboard_muted: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["modified_at", b"modified_at", "muted", b"muted", "soundboard_muted", b"soundboard_muted", "volume", b"volume"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class AudioSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class UserEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___PreloadedUserSettings.AudioContextSetting: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___PreloadedUserSettings.AudioContextSetting | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        @_typing.final
        class StreamEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___PreloadedUserSettings.AudioContextSetting: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___PreloadedUserSettings.AudioContextSetting | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        USER_FIELD_NUMBER: _builtins.int
        STREAM_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def user(self) -> _containers.MessageMap[_builtins.int, Global___PreloadedUserSettings.AudioContextSetting]: ...
        @_builtins.property
        def stream(self) -> _containers.MessageMap[_builtins.int, Global___PreloadedUserSettings.AudioContextSetting]: ...
        def __init__(
            self,
            *,
            user: _abc.Mapping[_builtins.int, Global___PreloadedUserSettings.AudioContextSetting] | None = ...,
            stream: _abc.Mapping[_builtins.int, Global___PreloadedUserSettings.AudioContextSetting] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["stream", b"stream", "user", b"user"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class CommunitiesSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        DISABLE_HOME_AUTO_NAV_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def disable_home_auto_nav(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            disable_home_auto_nav: _wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_disable_home_auto_nav", b"_disable_home_auto_nav", "disable_home_auto_nav", b"disable_home_auto_nav"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_disable_home_auto_nav", b"_disable_home_auto_nav", "disable_home_auto_nav", b"disable_home_auto_nav"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__disable_home_auto_nav: _TypeAlias = _typing.Literal["disable_home_auto_nav"]  # noqa: Y015
        _WhichOneofArgType__disable_home_auto_nav: _TypeAlias = _typing.Literal["_disable_home_auto_nav", b"_disable_home_auto_nav"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__disable_home_auto_nav) -> _WhichOneofReturnType__disable_home_auto_nav | None: ...

    @_typing.final
    class BroadcastSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ALLOW_FRIENDS_FIELD_NUMBER: _builtins.int
        ALLOWED_GUILD_IDS_FIELD_NUMBER: _builtins.int
        ALLOWED_USER_IDS_FIELD_NUMBER: _builtins.int
        AUTO_BROADCAST_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def allow_friends(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def allowed_guild_ids(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        @_builtins.property
        def allowed_user_ids(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        @_builtins.property
        def auto_broadcast(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            allow_friends: _wrappers_pb2.BoolValue | None = ...,
            allowed_guild_ids: _abc.Iterable[_builtins.int] | None = ...,
            allowed_user_ids: _abc.Iterable[_builtins.int] | None = ...,
            auto_broadcast: _wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_allow_friends", b"_allow_friends", "_auto_broadcast", b"_auto_broadcast", "allow_friends", b"allow_friends", "auto_broadcast", b"auto_broadcast"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_allow_friends", b"_allow_friends", "_auto_broadcast", b"_auto_broadcast", "allow_friends", b"allow_friends", "allowed_guild_ids", b"allowed_guild_ids", "allowed_user_ids", b"allowed_user_ids", "auto_broadcast", b"auto_broadcast"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__allow_friends: _TypeAlias = _typing.Literal["allow_friends"]  # noqa: Y015
        _WhichOneofArgType__allow_friends: _TypeAlias = _typing.Literal["_allow_friends", b"_allow_friends"]  # noqa: Y015
        _WhichOneofReturnType__auto_broadcast: _TypeAlias = _typing.Literal["auto_broadcast"]  # noqa: Y015
        _WhichOneofArgType__auto_broadcast: _TypeAlias = _typing.Literal["_auto_broadcast", b"_auto_broadcast"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__allow_friends) -> _WhichOneofReturnType__allow_friends | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__auto_broadcast) -> _WhichOneofReturnType__auto_broadcast | None: ...

    @_typing.final
    class ClipsSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ALLOW_VOICE_RECORDING_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def allow_voice_recording(self) -> _wrappers_pb2.BoolValue: ...
        def __init__(
            self,
            *,
            allow_voice_recording: _wrappers_pb2.BoolValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_allow_voice_recording", b"_allow_voice_recording", "allow_voice_recording", b"allow_voice_recording"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_allow_voice_recording", b"_allow_voice_recording", "allow_voice_recording", b"allow_voice_recording"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__allow_voice_recording: _TypeAlias = _typing.Literal["allow_voice_recording"]  # noqa: Y015
        _WhichOneofArgType__allow_voice_recording: _TypeAlias = _typing.Literal["_allow_voice_recording", b"_allow_voice_recording"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__allow_voice_recording) -> _WhichOneofReturnType__allow_voice_recording | None: ...

    @_typing.final
    class ForLaterSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        CURRENT_TAB_FIELD_NUMBER: _builtins.int
        current_tab: Global___PreloadedUserSettings.ForLaterTab.ValueType
        def __init__(
            self,
            *,
            current_tab: Global___PreloadedUserSettings.ForLaterTab.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["current_tab", b"current_tab"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SpendingLimit(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        AMOUNT_FIELD_NUMBER: _builtins.int
        CURRENCY_FIELD_NUMBER: _builtins.int
        amount: _builtins.int
        currency: _builtins.str
        def __init__(
            self,
            *,
            amount: _builtins.int = ...,
            currency: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["amount", b"amount", "currency", b"currency"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SpendingLimitSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ONE_TIME_PURCHASE_LIMIT_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def one_time_purchase_limit(self) -> Global___PreloadedUserSettings.SpendingLimit: ...
        def __init__(
            self,
            *,
            one_time_purchase_limit: Global___PreloadedUserSettings.SpendingLimit | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_one_time_purchase_limit", b"_one_time_purchase_limit", "one_time_purchase_limit", b"one_time_purchase_limit"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_one_time_purchase_limit", b"_one_time_purchase_limit", "one_time_purchase_limit", b"one_time_purchase_limit"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__one_time_purchase_limit: _TypeAlias = _typing.Literal["one_time_purchase_limit"]  # noqa: Y015
        _WhichOneofArgType__one_time_purchase_limit: _TypeAlias = _typing.Literal["_one_time_purchase_limit", b"_one_time_purchase_limit"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__one_time_purchase_limit) -> _WhichOneofReturnType__one_time_purchase_limit | None: ...

    @_typing.final
    class SafetySettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        SAFETY_SETTINGS_PRESET_FIELD_NUMBER: _builtins.int
        IGNORE_PROFILE_SPEEDBUMP_DISABLED_FIELD_NUMBER: _builtins.int
        SPENDING_LIMIT_SETTINGS_FIELD_NUMBER: _builtins.int
        safety_settings_preset: Global___PreloadedUserSettings.SafetySettingsPresetType.ValueType
        ignore_profile_speedbump_disabled: _builtins.bool
        @_builtins.property
        def spending_limit_settings(self) -> Global___PreloadedUserSettings.SpendingLimitSettings: ...
        def __init__(
            self,
            *,
            safety_settings_preset: Global___PreloadedUserSettings.SafetySettingsPresetType.ValueType = ...,
            ignore_profile_speedbump_disabled: _builtins.bool = ...,
            spending_limit_settings: Global___PreloadedUserSettings.SpendingLimitSettings | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_spending_limit_settings", b"_spending_limit_settings", "spending_limit_settings", b"spending_limit_settings"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_spending_limit_settings", b"_spending_limit_settings", "ignore_profile_speedbump_disabled", b"ignore_profile_speedbump_disabled", "safety_settings_preset", b"safety_settings_preset", "spending_limit_settings", b"spending_limit_settings"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__spending_limit_settings: _TypeAlias = _typing.Literal["spending_limit_settings"]  # noqa: Y015
        _WhichOneofArgType__spending_limit_settings: _TypeAlias = _typing.Literal["_spending_limit_settings", b"_spending_limit_settings"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__spending_limit_settings) -> _WhichOneofReturnType__spending_limit_settings | None: ...

    @_typing.final
    class ICYMISettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        FEED_GENERATED_AT_FIELD_NUMBER: _builtins.int
        feed_generated_at: _builtins.int
        def __init__(
            self,
            *,
            feed_generated_at: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["feed_generated_at", b"feed_generated_at"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class ApplicationDMSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ALLOW_MOBILE_PUSH_FIELD_NUMBER: _builtins.int
        allow_mobile_push: _builtins.bool
        def __init__(
            self,
            *,
            allow_mobile_push: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["allow_mobile_push", b"allow_mobile_push"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class ApplicationSharingSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        DISABLE_APPLICATION_ACTIVITY_SHARING_FIELD_NUMBER: _builtins.int
        disable_application_activity_sharing: _builtins.bool
        def __init__(
            self,
            *,
            disable_application_activity_sharing: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["disable_application_activity_sharing", b"disable_application_activity_sharing"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class ApplicationSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        APP_DM_SETTINGS_FIELD_NUMBER: _builtins.int
        APP_SHARING_SETTINGS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def app_dm_settings(self) -> Global___PreloadedUserSettings.ApplicationDMSettings: ...
        @_builtins.property
        def app_sharing_settings(self) -> Global___PreloadedUserSettings.ApplicationSharingSettings: ...
        def __init__(
            self,
            *,
            app_dm_settings: Global___PreloadedUserSettings.ApplicationDMSettings | None = ...,
            app_sharing_settings: Global___PreloadedUserSettings.ApplicationSharingSettings | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_app_dm_settings", b"_app_dm_settings", "_app_sharing_settings", b"_app_sharing_settings", "app_dm_settings", b"app_dm_settings", "app_sharing_settings", b"app_sharing_settings"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_app_dm_settings", b"_app_dm_settings", "_app_sharing_settings", b"_app_sharing_settings", "app_dm_settings", b"app_dm_settings", "app_sharing_settings", b"app_sharing_settings"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__app_dm_settings: _TypeAlias = _typing.Literal["app_dm_settings"]  # noqa: Y015
        _WhichOneofArgType__app_dm_settings: _TypeAlias = _typing.Literal["_app_dm_settings", b"_app_dm_settings"]  # noqa: Y015
        _WhichOneofReturnType__app_sharing_settings: _TypeAlias = _typing.Literal["app_sharing_settings"]  # noqa: Y015
        _WhichOneofArgType__app_sharing_settings: _TypeAlias = _typing.Literal["_app_sharing_settings", b"_app_sharing_settings"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__app_dm_settings) -> _WhichOneofReturnType__app_dm_settings | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__app_sharing_settings) -> _WhichOneofReturnType__app_sharing_settings | None: ...

    @_typing.final
    class AllApplicationSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class AppSettingsEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___PreloadedUserSettings.ApplicationSettings: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___PreloadedUserSettings.ApplicationSettings | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        APP_SETTINGS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def app_settings(self) -> _containers.MessageMap[_builtins.int, Global___PreloadedUserSettings.ApplicationSettings]: ...
        def __init__(
            self,
            *,
            app_settings: _abc.Mapping[_builtins.int, Global___PreloadedUserSettings.ApplicationSettings] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["app_settings", b"app_settings"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class AdsSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ALWAYS_DELIVER_FIELD_NUMBER: _builtins.int
        always_deliver: _builtins.bool
        def __init__(
            self,
            *,
            always_deliver: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["always_deliver", b"always_deliver"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class InAppFeedbackState(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LAST_IMPRESSION_TIME_FIELD_NUMBER: _builtins.int
        OPT_OUT_EXPIRY_TIME_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def last_impression_time(self) -> _wrappers_pb2.UInt64Value: ...
        @_builtins.property
        def opt_out_expiry_time(self) -> _wrappers_pb2.UInt64Value: ...
        def __init__(
            self,
            *,
            last_impression_time: _wrappers_pb2.UInt64Value | None = ...,
            opt_out_expiry_time: _wrappers_pb2.UInt64Value | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_last_impression_time", b"_last_impression_time", "_opt_out_expiry_time", b"_opt_out_expiry_time", "last_impression_time", b"last_impression_time", "opt_out_expiry_time", b"opt_out_expiry_time"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_last_impression_time", b"_last_impression_time", "_opt_out_expiry_time", b"_opt_out_expiry_time", "last_impression_time", b"last_impression_time", "opt_out_expiry_time", b"opt_out_expiry_time"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__last_impression_time: _TypeAlias = _typing.Literal["last_impression_time"]  # noqa: Y015
        _WhichOneofArgType__last_impression_time: _TypeAlias = _typing.Literal["_last_impression_time", b"_last_impression_time"]  # noqa: Y015
        _WhichOneofReturnType__opt_out_expiry_time: _TypeAlias = _typing.Literal["opt_out_expiry_time"]  # noqa: Y015
        _WhichOneofArgType__opt_out_expiry_time: _TypeAlias = _typing.Literal["_opt_out_expiry_time", b"_opt_out_expiry_time"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__last_impression_time) -> _WhichOneofReturnType__last_impression_time | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__opt_out_expiry_time) -> _WhichOneofReturnType__opt_out_expiry_time | None: ...

    @_typing.final
    class InAppFeedbackSettings(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class InAppFeedbackStatesEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___PreloadedUserSettings.InAppFeedbackState: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___PreloadedUserSettings.InAppFeedbackState | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        IN_APP_FEEDBACK_STATES_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def in_app_feedback_states(self) -> _containers.MessageMap[_builtins.int, Global___PreloadedUserSettings.InAppFeedbackState]: ...
        def __init__(
            self,
            *,
            in_app_feedback_states: _abc.Mapping[_builtins.int, Global___PreloadedUserSettings.InAppFeedbackState] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["in_app_feedback_states", b"in_app_feedback_states"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    VERSIONS_FIELD_NUMBER: _builtins.int
    INBOX_FIELD_NUMBER: _builtins.int
    GUILDS_FIELD_NUMBER: _builtins.int
    USER_CONTENT_FIELD_NUMBER: _builtins.int
    VOICE_AND_VIDEO_FIELD_NUMBER: _builtins.int
    TEXT_AND_IMAGES_FIELD_NUMBER: _builtins.int
    NOTIFICATIONS_FIELD_NUMBER: _builtins.int
    PRIVACY_FIELD_NUMBER: _builtins.int
    DEBUG_FIELD_NUMBER: _builtins.int
    GAME_LIBRARY_FIELD_NUMBER: _builtins.int
    STATUS_FIELD_NUMBER: _builtins.int
    LOCALIZATION_FIELD_NUMBER: _builtins.int
    APPEARANCE_FIELD_NUMBER: _builtins.int
    GUILD_FOLDERS_FIELD_NUMBER: _builtins.int
    FAVORITES_FIELD_NUMBER: _builtins.int
    AUDIO_CONTEXT_SETTINGS_FIELD_NUMBER: _builtins.int
    COMMUNITIES_FIELD_NUMBER: _builtins.int
    BROADCAST_FIELD_NUMBER: _builtins.int
    CLIPS_FIELD_NUMBER: _builtins.int
    FOR_LATER_FIELD_NUMBER: _builtins.int
    SAFETY_SETTINGS_FIELD_NUMBER: _builtins.int
    ICYMI_SETTINGS_FIELD_NUMBER: _builtins.int
    APPLICATIONS_FIELD_NUMBER: _builtins.int
    ADS_FIELD_NUMBER: _builtins.int
    IN_APP_FEEDBACK_SETTINGS_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def versions(self) -> Global___PreloadedUserSettings.Versions: ...
    @_builtins.property
    def inbox(self) -> Global___PreloadedUserSettings.InboxSettings: ...
    @_builtins.property
    def guilds(self) -> Global___PreloadedUserSettings.AllGuildSettings: ...
    @_builtins.property
    def user_content(self) -> Global___PreloadedUserSettings.UserContentSettings: ...
    @_builtins.property
    def voice_and_video(self) -> Global___PreloadedUserSettings.VoiceAndVideoSettings: ...
    @_builtins.property
    def text_and_images(self) -> Global___PreloadedUserSettings.TextAndImagesSettings: ...
    @_builtins.property
    def notifications(self) -> Global___PreloadedUserSettings.NotificationSettings: ...
    @_builtins.property
    def privacy(self) -> Global___PreloadedUserSettings.PrivacySettings: ...
    @_builtins.property
    def debug(self) -> Global___PreloadedUserSettings.DebugSettings: ...
    @_builtins.property
    def game_library(self) -> Global___PreloadedUserSettings.GameLibrarySettings: ...
    @_builtins.property
    def status(self) -> Global___PreloadedUserSettings.StatusSettings: ...
    @_builtins.property
    def localization(self) -> Global___PreloadedUserSettings.LocalizationSettings: ...
    @_builtins.property
    def appearance(self) -> Global___PreloadedUserSettings.AppearanceSettings: ...
    @_builtins.property
    def guild_folders(self) -> Global___PreloadedUserSettings.GuildFolders: ...
    @_builtins.property
    def favorites(self) -> Global___PreloadedUserSettings.Favorites: ...
    @_builtins.property
    def audio_context_settings(self) -> Global___PreloadedUserSettings.AudioSettings: ...
    @_builtins.property
    def communities(self) -> Global___PreloadedUserSettings.CommunitiesSettings: ...
    @_builtins.property
    def broadcast(self) -> Global___PreloadedUserSettings.BroadcastSettings: ...
    @_builtins.property
    def clips(self) -> Global___PreloadedUserSettings.ClipsSettings: ...
    @_builtins.property
    def for_later(self) -> Global___PreloadedUserSettings.ForLaterSettings: ...
    @_builtins.property
    def safety_settings(self) -> Global___PreloadedUserSettings.SafetySettings: ...
    @_builtins.property
    def icymi_settings(self) -> Global___PreloadedUserSettings.ICYMISettings: ...
    @_builtins.property
    def applications(self) -> Global___PreloadedUserSettings.AllApplicationSettings: ...
    @_builtins.property
    def ads(self) -> Global___PreloadedUserSettings.AdsSettings: ...
    @_builtins.property
    def in_app_feedback_settings(self) -> Global___PreloadedUserSettings.InAppFeedbackSettings: ...
    def __init__(
        self,
        *,
        versions: Global___PreloadedUserSettings.Versions | None = ...,
        inbox: Global___PreloadedUserSettings.InboxSettings | None = ...,
        guilds: Global___PreloadedUserSettings.AllGuildSettings | None = ...,
        user_content: Global___PreloadedUserSettings.UserContentSettings | None = ...,
        voice_and_video: Global___PreloadedUserSettings.VoiceAndVideoSettings | None = ...,
        text_and_images: Global___PreloadedUserSettings.TextAndImagesSettings | None = ...,
        notifications: Global___PreloadedUserSettings.NotificationSettings | None = ...,
        privacy: Global___PreloadedUserSettings.PrivacySettings | None = ...,
        debug: Global___PreloadedUserSettings.DebugSettings | None = ...,
        game_library: Global___PreloadedUserSettings.GameLibrarySettings | None = ...,
        status: Global___PreloadedUserSettings.StatusSettings | None = ...,
        localization: Global___PreloadedUserSettings.LocalizationSettings | None = ...,
        appearance: Global___PreloadedUserSettings.AppearanceSettings | None = ...,
        guild_folders: Global___PreloadedUserSettings.GuildFolders | None = ...,
        favorites: Global___PreloadedUserSettings.Favorites | None = ...,
        audio_context_settings: Global___PreloadedUserSettings.AudioSettings | None = ...,
        communities: Global___PreloadedUserSettings.CommunitiesSettings | None = ...,
        broadcast: Global___PreloadedUserSettings.BroadcastSettings | None = ...,
        clips: Global___PreloadedUserSettings.ClipsSettings | None = ...,
        for_later: Global___PreloadedUserSettings.ForLaterSettings | None = ...,
        safety_settings: Global___PreloadedUserSettings.SafetySettings | None = ...,
        icymi_settings: Global___PreloadedUserSettings.ICYMISettings | None = ...,
        applications: Global___PreloadedUserSettings.AllApplicationSettings | None = ...,
        ads: Global___PreloadedUserSettings.AdsSettings | None = ...,
        in_app_feedback_settings: Global___PreloadedUserSettings.InAppFeedbackSettings | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_ads", b"_ads", "_appearance", b"_appearance", "_applications", b"_applications", "_audio_context_settings", b"_audio_context_settings", "_broadcast", b"_broadcast", "_clips", b"_clips", "_communities", b"_communities", "_debug", b"_debug", "_favorites", b"_favorites", "_for_later", b"_for_later", "_game_library", b"_game_library", "_guild_folders", b"_guild_folders", "_guilds", b"_guilds", "_icymi_settings", b"_icymi_settings", "_in_app_feedback_settings", b"_in_app_feedback_settings", "_inbox", b"_inbox", "_localization", b"_localization", "_notifications", b"_notifications", "_privacy", b"_privacy", "_safety_settings", b"_safety_settings", "_status", b"_status", "_text_and_images", b"_text_and_images", "_user_content", b"_user_content", "_versions", b"_versions", "_voice_and_video", b"_voice_and_video", "ads", b"ads", "appearance", b"appearance", "applications", b"applications", "audio_context_settings", b"audio_context_settings", "broadcast", b"broadcast", "clips", b"clips", "communities", b"communities", "debug", b"debug", "favorites", b"favorites", "for_later", b"for_later", "game_library", b"game_library", "guild_folders", b"guild_folders", "guilds", b"guilds", "icymi_settings", b"icymi_settings", "in_app_feedback_settings", b"in_app_feedback_settings", "inbox", b"inbox", "localization", b"localization", "notifications", b"notifications", "privacy", b"privacy", "safety_settings", b"safety_settings", "status", b"status", "text_and_images", b"text_and_images", "user_content", b"user_content", "versions", b"versions", "voice_and_video", b"voice_and_video"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_ads", b"_ads", "_appearance", b"_appearance", "_applications", b"_applications", "_audio_context_settings", b"_audio_context_settings", "_broadcast", b"_broadcast", "_clips", b"_clips", "_communities", b"_communities", "_debug", b"_debug", "_favorites", b"_favorites", "_for_later", b"_for_later", "_game_library", b"_game_library", "_guild_folders", b"_guild_folders", "_guilds", b"_guilds", "_icymi_settings", b"_icymi_settings", "_in_app_feedback_settings", b"_in_app_feedback_settings", "_inbox", b"_inbox", "_localization", b"_localization", "_notifications", b"_notifications", "_privacy", b"_privacy", "_safety_settings", b"_safety_settings", "_status", b"_status", "_text_and_images", b"_text_and_images", "_user_content", b"_user_content", "_versions", b"_versions", "_voice_and_video", b"_voice_and_video", "ads", b"ads", "appearance", b"appearance", "applications", b"applications", "audio_context_settings", b"audio_context_settings", "broadcast", b"broadcast", "clips", b"clips", "communities", b"communities", "debug", b"debug", "favorites", b"favorites", "for_later", b"for_later", "game_library", b"game_library", "guild_folders", b"guild_folders", "guilds", b"guilds", "icymi_settings", b"icymi_settings", "in_app_feedback_settings", b"in_app_feedback_settings", "inbox", b"inbox", "localization", b"localization", "notifications", b"notifications", "privacy", b"privacy", "safety_settings", b"safety_settings", "status", b"status", "text_and_images", b"text_and_images", "user_content", b"user_content", "versions", b"versions", "voice_and_video", b"voice_and_video"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__ads: _TypeAlias = _typing.Literal["ads"]  # noqa: Y015
    _WhichOneofArgType__ads: _TypeAlias = _typing.Literal["_ads", b"_ads"]  # noqa: Y015
    _WhichOneofReturnType__appearance: _TypeAlias = _typing.Literal["appearance"]  # noqa: Y015
    _WhichOneofArgType__appearance: _TypeAlias = _typing.Literal["_appearance", b"_appearance"]  # noqa: Y015
    _WhichOneofReturnType__applications: _TypeAlias = _typing.Literal["applications"]  # noqa: Y015
    _WhichOneofArgType__applications: _TypeAlias = _typing.Literal["_applications", b"_applications"]  # noqa: Y015
    _WhichOneofReturnType__audio_context_settings: _TypeAlias = _typing.Literal["audio_context_settings"]  # noqa: Y015
    _WhichOneofArgType__audio_context_settings: _TypeAlias = _typing.Literal["_audio_context_settings", b"_audio_context_settings"]  # noqa: Y015
    _WhichOneofReturnType__broadcast: _TypeAlias = _typing.Literal["broadcast"]  # noqa: Y015
    _WhichOneofArgType__broadcast: _TypeAlias = _typing.Literal["_broadcast", b"_broadcast"]  # noqa: Y015
    _WhichOneofReturnType__clips: _TypeAlias = _typing.Literal["clips"]  # noqa: Y015
    _WhichOneofArgType__clips: _TypeAlias = _typing.Literal["_clips", b"_clips"]  # noqa: Y015
    _WhichOneofReturnType__communities: _TypeAlias = _typing.Literal["communities"]  # noqa: Y015
    _WhichOneofArgType__communities: _TypeAlias = _typing.Literal["_communities", b"_communities"]  # noqa: Y015
    _WhichOneofReturnType__debug: _TypeAlias = _typing.Literal["debug"]  # noqa: Y015
    _WhichOneofArgType__debug: _TypeAlias = _typing.Literal["_debug", b"_debug"]  # noqa: Y015
    _WhichOneofReturnType__favorites: _TypeAlias = _typing.Literal["favorites"]  # noqa: Y015
    _WhichOneofArgType__favorites: _TypeAlias = _typing.Literal["_favorites", b"_favorites"]  # noqa: Y015
    _WhichOneofReturnType__for_later: _TypeAlias = _typing.Literal["for_later"]  # noqa: Y015
    _WhichOneofArgType__for_later: _TypeAlias = _typing.Literal["_for_later", b"_for_later"]  # noqa: Y015
    _WhichOneofReturnType__game_library: _TypeAlias = _typing.Literal["game_library"]  # noqa: Y015
    _WhichOneofArgType__game_library: _TypeAlias = _typing.Literal["_game_library", b"_game_library"]  # noqa: Y015
    _WhichOneofReturnType__guild_folders: _TypeAlias = _typing.Literal["guild_folders"]  # noqa: Y015
    _WhichOneofArgType__guild_folders: _TypeAlias = _typing.Literal["_guild_folders", b"_guild_folders"]  # noqa: Y015
    _WhichOneofReturnType__guilds: _TypeAlias = _typing.Literal["guilds"]  # noqa: Y015
    _WhichOneofArgType__guilds: _TypeAlias = _typing.Literal["_guilds", b"_guilds"]  # noqa: Y015
    _WhichOneofReturnType__icymi_settings: _TypeAlias = _typing.Literal["icymi_settings"]  # noqa: Y015
    _WhichOneofArgType__icymi_settings: _TypeAlias = _typing.Literal["_icymi_settings", b"_icymi_settings"]  # noqa: Y015
    _WhichOneofReturnType__in_app_feedback_settings: _TypeAlias = _typing.Literal["in_app_feedback_settings"]  # noqa: Y015
    _WhichOneofArgType__in_app_feedback_settings: _TypeAlias = _typing.Literal["_in_app_feedback_settings", b"_in_app_feedback_settings"]  # noqa: Y015
    _WhichOneofReturnType__inbox: _TypeAlias = _typing.Literal["inbox"]  # noqa: Y015
    _WhichOneofArgType__inbox: _TypeAlias = _typing.Literal["_inbox", b"_inbox"]  # noqa: Y015
    _WhichOneofReturnType__localization: _TypeAlias = _typing.Literal["localization"]  # noqa: Y015
    _WhichOneofArgType__localization: _TypeAlias = _typing.Literal["_localization", b"_localization"]  # noqa: Y015
    _WhichOneofReturnType__notifications: _TypeAlias = _typing.Literal["notifications"]  # noqa: Y015
    _WhichOneofArgType__notifications: _TypeAlias = _typing.Literal["_notifications", b"_notifications"]  # noqa: Y015
    _WhichOneofReturnType__privacy: _TypeAlias = _typing.Literal["privacy"]  # noqa: Y015
    _WhichOneofArgType__privacy: _TypeAlias = _typing.Literal["_privacy", b"_privacy"]  # noqa: Y015
    _WhichOneofReturnType__safety_settings: _TypeAlias = _typing.Literal["safety_settings"]  # noqa: Y015
    _WhichOneofArgType__safety_settings: _TypeAlias = _typing.Literal["_safety_settings", b"_safety_settings"]  # noqa: Y015
    _WhichOneofReturnType__status: _TypeAlias = _typing.Literal["status"]  # noqa: Y015
    _WhichOneofArgType__status: _TypeAlias = _typing.Literal["_status", b"_status"]  # noqa: Y015
    _WhichOneofReturnType__text_and_images: _TypeAlias = _typing.Literal["text_and_images"]  # noqa: Y015
    _WhichOneofArgType__text_and_images: _TypeAlias = _typing.Literal["_text_and_images", b"_text_and_images"]  # noqa: Y015
    _WhichOneofReturnType__user_content: _TypeAlias = _typing.Literal["user_content"]  # noqa: Y015
    _WhichOneofArgType__user_content: _TypeAlias = _typing.Literal["_user_content", b"_user_content"]  # noqa: Y015
    _WhichOneofReturnType__versions: _TypeAlias = _typing.Literal["versions"]  # noqa: Y015
    _WhichOneofArgType__versions: _TypeAlias = _typing.Literal["_versions", b"_versions"]  # noqa: Y015
    _WhichOneofReturnType__voice_and_video: _TypeAlias = _typing.Literal["voice_and_video"]  # noqa: Y015
    _WhichOneofArgType__voice_and_video: _TypeAlias = _typing.Literal["_voice_and_video", b"_voice_and_video"]  # noqa: Y015
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__ads) -> _WhichOneofReturnType__ads | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__appearance) -> _WhichOneofReturnType__appearance | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__applications) -> _WhichOneofReturnType__applications | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__audio_context_settings) -> _WhichOneofReturnType__audio_context_settings | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__broadcast) -> _WhichOneofReturnType__broadcast | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__clips) -> _WhichOneofReturnType__clips | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__communities) -> _WhichOneofReturnType__communities | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__debug) -> _WhichOneofReturnType__debug | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__favorites) -> _WhichOneofReturnType__favorites | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__for_later) -> _WhichOneofReturnType__for_later | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__game_library) -> _WhichOneofReturnType__game_library | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__guild_folders) -> _WhichOneofReturnType__guild_folders | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__guilds) -> _WhichOneofReturnType__guilds | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__icymi_settings) -> _WhichOneofReturnType__icymi_settings | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__in_app_feedback_settings) -> _WhichOneofReturnType__in_app_feedback_settings | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__inbox) -> _WhichOneofReturnType__inbox | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__localization) -> _WhichOneofReturnType__localization | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__notifications) -> _WhichOneofReturnType__notifications | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__privacy) -> _WhichOneofReturnType__privacy | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__safety_settings) -> _WhichOneofReturnType__safety_settings | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__status) -> _WhichOneofReturnType__status | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__text_and_images) -> _WhichOneofReturnType__text_and_images | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__user_content) -> _WhichOneofReturnType__user_content | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__versions) -> _WhichOneofReturnType__versions | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__voice_and_video) -> _WhichOneofReturnType__voice_and_video | None: ...

Global___PreloadedUserSettings: _TypeAlias = PreloadedUserSettings  # noqa: Y015
